<?php
/**
 * Media Manager Images Field
 *
 * @author Rascals Themes
 * @category Core
 * @package Noisa Toolkit
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed diCustomizer
}

if ( ! function_exists( 'rascals_media_manager_images' ) ) :

	function rascals_media_manager_images( $type, $id, $item, $options, $custom ) {
   
		/* Display only if the type matches */
		if ( $type === 'images' ) {

			/* Output */
			$output = '';

			/* Defaults */
			$defaults = [
				'custom'      => $custom,
				'title'       => '',
				'custom_link' => '',
				'thumb_icon'  => 'view',
			];

			/* Set default options */
			if ( isset( $options ) && is_array( $options ) ) {
				$options = array_merge( $defaults, $options );
			} else {
				$options = $defaults;
			}

			/* Helpers */

			/* Target options */
			$target_options = [
				[ 'name' => esc_html__( 'Same Window/Tab', 'noisa-toolkit' ), 'value' => '_self' ],
				[ 'name' => esc_html__( 'New Window/Tab', 'noisa-toolkit' ), 'value' => '_blank' ],
			];

			/* Yes/No */
			$yes_no_options = [
				[ 'name' => esc_html__( 'No', 'noisa-toolkit' ), 'value' => 'no' ],
				[ 'name' => esc_html__( 'Yes', 'noisa-toolkit' ), 'value' => 'yes' ],
			];

			/*
				IMAGE META 
			------------------------------------------------------------------------------*/
			/* Get Image Data */
			$meta       = wp_get_attachment_metadata( $id );
			$image_data = wp_get_attachment_image_src( $id );

			$output .= '
			<div class="mm-item mm-item-editor" id="' . esc_attr( $id ) . '">
				<div class="mm-item-preview">
			    	<div class="mm-item-image">
			    		<div class="mm-centered">
			    			<a href="' . esc_url( $item->guid ) . '" target="_blank"><img src="' . esc_url( $image_data[0] ) . '" /></a>
			    		</div>
			    	</div>
				</div>
			</div>';
		
			/* Meta */
			$output .= '<div id="mm-editor-meta">';
			$output .= '<span><strong>' . esc_html__( 'File name:', 'noisa-toolkit' ) . '</strong> ' . esc_html( basename( $item->guid ) ) . '</span>';
			$output .= '<span><strong>' . esc_html__( 'File type:', 'noisa-toolkit' ) . '</strong> ' . esc_html( $item->post_mime_type ) . '</span>';
			$output .= '<span><strong>' . esc_html__( 'Upload date:', 'noisa-toolkit' ) . '</strong> ' . mysql2date( get_option( 'date_format' ), $item->post_date ) . '</span>';

			if ( is_array( $meta ) && array_key_exists( 'width', $meta ) && array_key_exists( 'height', $meta ) ) {
				$output .= '<span><strong>' . esc_html__( 'Dimensions:', 'noisa-toolkit' ) . '</strong> ' . esc_html( $meta['width'] ) . ' x ' . esc_html( $meta['height'] ) . '</span>';
			}

			$output .= '<span><strong>' . esc_html__( 'Image URL:', 'noisa-toolkit' ) . '</strong> <br>
			<a href="' . esc_url( $item->guid ) . '" target="_blank">' . esc_html__( '[IMAGE LINK]', 'noisa-toolkit' ) . '</a>
			</span>';

			$output .= '</div>';


			/*
				FIELDS
			------------------------------------------------------------------------------*/

			$output .= '<fieldset class="rascalsbox">';
				
			/* Title */
			$output .= '
			<div class="box-row clearfix">
				<div class="box-row-input">
					<div class="box-tc box-tc-label">
						<label for="mm-image-title">' . esc_html__( 'Title', 'noisa-toolkit' ) . '</label>
					</div>
					<div class="box-tc box-tc-input">
						<input type="text" id="mm-image-title" name="title" value="' . esc_attr( $options['title'] ) . '" />
						<p class="help-box">' . esc_html__( 'Image title.', 'noisa-toolkit' ) . '</p>
					</div>
				</div>
				<div class="box-row-line"></div>
			</div>';
		

			/* Custom Link */
			$output .= '
			<div class="box-row clearfix">
				<div class="box-row-input">
					<div class="box-tc box-tc-label">
						<label for="mm-image-custom-link">' . esc_html__( 'Custom Link', 'noisa-toolkit' ) . '</label>
					</div>
					<div class="box-tc box-tc-input">
						<textarea id="mm-custom-link" name="custom_link" style="min-height:40px">' . wp_kses_post( $options['custom_link'] ) . '</textarea>
						<p class="help-box">' . esc_html__( 'Add custom link to popup window.', 'noisa-toolkit' ) . '</p>
					</div>
				</div>
				<div class="box-row-line"></div>
			</div>';


			/* Icons  */
			$output .= '
			<div class="box-row clearfix">
				<div class="box-row-input">
					<div class="box-tc box-tc-label">
						<label for="mm-thumb-icon">' . esc_html__( 'Thumbnail Icon', 'noisa-toolkit' ) . '</label>
					</div>
					<div class="box-tc box-tc-input">
						<select id="mm-thumb-icon" name="thumb_icon" size="1" class="box-select">';

				/* Icons options */
				$icon_options = [
					[ 'name' => 'Preview', 'value' => 'view' ],
					[ 'name' => 'Plus', 'value' => 'plus' ],
					[ 'name' => 'Video', 'value' => 'video' ],
					[ 'name' => 'Soundcloud', 'value' => 'soundcloud' ],
					[ 'name' => 'Headphones', 'value' => 'headphones' ],
				];

				foreach ( $icon_options as $option ) {
					
					if ( $options['thumb_icon'] == $option['value'] ) {
						$selected = 'selected';
					} else { 
						$selected = '';
					}
					$output .= '<option ' . esc_attr( $selected ) . " value='" . esc_attr( $option['value'] ) . "'>" . esc_attr( $option['name'] ) . '</option>';
				}

				$output .= '</select>';
				$output .= '<p class="help-box">' . esc_html__( 'Select thumb icon.', 'noisa-toolkit' ) . '</p>
					</div>
				</div>
				<div class="box-row-line"></div>
			</div>';

				$output .= '</fieldset>';

				return $output;
		}
	}

endif;
