<?php
/**
 * Rascals MetaBox
 *
 * Register Artists Metabox
 *
 * @author Rascals Themes
 * @category Core
 * @package Noisa Toolkit
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/*
==================================================
	Metaboxes options
================================================== */
function noisa_toolkit_mb_artists() {

	$rascals_mb = NoisaToolkit::getInstance()->metaboxes;


	/*
	==================================================
		Single Artists
	================================================== */

	/* Meta info */ 
	$meta_info = [
		'title'    => esc_html__( 'Artist Options', 'noisa-toolkit' ), 
		'id'       => 'rascals_mb_artist_post', 
		'page'     => [
			'noisa_artists',
		], 
		'context'  => 'normal', 
		'priority' => 'high', 
		'callback' => '', 
		'template' => [ 
			'post',
		],
	];

	/* Box Filter */
	if ( has_filter( 'rascals_mb_artist_post_box' ) ) {
		$meta_info = apply_filters( 'rascals_mb_artist_post_box', $meta_info );
	}

	/* Meta options */
	$meta_options = [


		/*
		TAB: LOOP
		-------------------------------- */
		[
			'name' => esc_html__( 'Loop Options', 'noisa-toolkit' ),
			'id'   => 'tab-loop',
			'type' => 'tab_open',
		],

		[
			'name'      => esc_html__( 'Tooltip', 'noisa-toolkit' ),
			'id'        => '_tooltip',
			'type'      => 'textarea',
			'std'       => '',
			'tinymce'   => 'false',
			'height'    => '100',
			'separator' => true,
			'desc'      => esc_html__( 'Add tooltip text ex:', 'noisa-toolkit' ) . '<br><pre><code>&lt;span>Tooltip Title&lt;/span>
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque porttitor fermentum ullamcorper. Aliquam erat volutpat.</code></pre>',
		],

		[
			'type' => 'tab_close',
		],

		/* Import: Tab: Intro */
		noisa_toolkit_mb_common( 'intro_tab' ),

		/* Import: Layout Tab */ 
		noisa_toolkit_mb_common( 'layout_tab' ),

		/* Import: Facebook Sharing */
		noisa_toolkit_mb_common( 'facebook_sharing_tab' ),

	];

	/* Options Filter */
	if ( has_filter( 'rascals_mb_artist_post_opts' ) ) {
		$meta_options = apply_filters( 'rascals_mb_artist_post_opts', $meta_options );
	}

	/* Add class instance */
	$rascals_mb_artist_post = new RascalsBox( $meta_options, $meta_info );


	/*
	==================================================
		Artists Template
	================================================== */

	/* Meta info */ 
	$meta_info = [
		'title'      => esc_html__( 'Artists Options', 'noisa-toolkit' ), 
		'id'         => 'rascals_mb_artist_template', 
		'page'       => [
			'page',
		], 
		'context'    => 'normal', 
		'priority'   => 'high', 
		'callback'   => '', 
		'template'   => [ 
			'page-templates/artists.php',
		],
		'textdomain' => 'noisa-toolkit',
	];

	/* Box Filter */
	if ( has_filter( 'rascals_mb_artist_template_box' ) ) {
		$meta_info = apply_filters( 'rascals_mb_artist_template_box', $meta_info );
	}

	/* Meta options */
	$meta_options = [
		
		
		/*
		TAB: GENERAL
		-------------------------------- */
		[
			'name' => esc_html__( 'General', 'noisa-toolkit' ),
			'id'   => 'tab-general',
			'type' => 'tab_open',
		],

		/* Limit */ 
		[
			'name'      => esc_html__( 'Artists Per Page', 'noisa-toolkit' ),
			'id'        => '_limit',
			'type'      => 'range',
			'std'       => '8',
			'min'       => 1,
			'max'       => 100,
			'unit'      => esc_html__( 'artists', 'noisa-toolkit' ),
			'separator' => true,
			'desc'      => esc_html__( 'Number of artists visible on page.', 'noisa-toolkit' ),
		],
			
		/* Gap */ 
		[
			'name'      => esc_html__( 'Thumbnails Gap', 'noisa-toolkit' ),
			'id'        => '_gap',
			'type'      => 'select',
			'std'       => 'no-gap',
			'options'   => [
				[ 'name' => esc_html__( 'Small Gap', 'noisa-toolkit' ), 'value' => 'no-gap' ],
				[ 'name' => esc_html__( 'Medium gap', 'noisa-toolkit' ), 'value' => 'medium-gap' ],
			],
			'separator' => true,
			'desc'      => esc_html__( 'Display gap between thumbnails.', 'noisa-toolkit' ),
		],

		/* Grid layout */ 
			[
				'name'      => esc_html__( 'Grid Layout', 'noisa-toolkit' ),
				'id'        => '_artists_layout',
				'type'      => 'select',
				'std'       => 'boxed',
				'options'   => [
					[ 'name' => esc_html__( 'Boxed', 'noisa-toolkit' ), 'value' => 'boxed' ],
					[ 'name' => esc_html__( 'Full width', 'noisa-toolkit' ), 'value' => 'full-width' ],
				],
				'separator' => true,
				'desc'      => esc_html__( 'Select grid layout.', 'noisa-toolkit' ),
			],

		/* Filters */ 
		[
			'name'       => esc_html__( 'Filters', 'noisa-toolkit' ),
			'id'         => '_filters',
			'type'       => 'multiselect',
			'std'        => [ 'genres', 'categories' ],
			'save_empty' => true,
			'options'    => [
				[ 'name' => esc_html__( 'Genres', 'noisa-toolkit' ), 'value' => 'genres' ],
				[ 'name' => esc_html__( 'Categories', 'noisa-toolkit' ), 'value' => 'categories' ],
			],
			'separator'  => true,
			'desc'       => esc_html__( 'Please use the CTRL key (PC) or COMMAND key (Mac) to select multiple filters.', 'noisa-toolkit' ),
		],


		[
			'type' => 'tab_close',
		],


		/* Import: Tab: Intro */
		noisa_toolkit_mb_common( 'intro_tab' ),

		/* Import: Facebook Sharing */
		noisa_toolkit_mb_common( 'facebook_sharing_tab' ),
		

	];

	/* Options Filter */
	if ( has_filter( 'rascals_mb_artist_template_opts' ) ) {
		$meta_options = apply_filters( 'rascals_mb_artist_template_opts', $meta_options );
	}

	/* Add class instance */
	$rascals_mb_artist_template = new RascalsBox( $meta_options, $meta_info );
}

return noisa_toolkit_mb_artists();
