<?php
/**
 * Rascals MetaBox
 *
 * Register Blog Metabox
 *
 * @author Rascals Themes
 * @category Core
 * @package Noisa Toolkit
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed diCustomizer
}


/*
==================================================
	Metaboxes options
================================================== */
function noisa_toolkit_mb_blog() {

	$rascals_mb = NoisaToolkit::getInstance()->metaboxes;


	/*
	==================================================
		Template: Blog Grid
	================================================== */

	/* Meta info */ 
	$meta_info = [
		'title'    => esc_html__( 'Blog Options', 'noisa-toolkit' ), 
		'id'       => 'rascals_mb_blog_grid', 
		'page'     => [
			'page',
		], 
		'context'  => 'normal', 
		'priority' => 'high', 
		'callback' => '', 
		'template' => [ 
			'page-templates/blog-grid.php',
		],
	];

	/* Box Filter */
	if ( has_filter( 'rascals_mb_blog_grid_box' ) ) {
		$meta_info = apply_filters( 'rascals_mb_blog_grid_box', $meta_info );
	}

	/* Meta options */
	$meta_options = [


		/*
		TAB: GENERAL
		-------------------------------- */
		[
			'name' => esc_html__( 'General', 'noisa-toolkit' ),
			'id'   => 'tab-general',
			'type' => 'tab_open',
		],
		/* Limit */
		[
			'name'      => esc_html__( 'Posts Per Page', 'noisa-toolkit' ),
			'id'        => '_limit',
			'type'      => 'range',
			'min'       => 1,
			'max'       => 100,
			'unit'      => esc_html__( 'items', 'noisa-toolkit' ),
			'std'       => '8',
			'separator' => true,
			'desc'      => esc_html__( 'Number of blog posts visible on page.', 'noisa-toolkit' ),
		],

		/* Grid Layout */
			[
				'name'    => esc_html__( 'Blog Grid Layout', 'noisa-toolkit' ),
				'id'      => '_blog_layout',
				'type'    => 'select',
				'std'     => 'boxed',
				'options' => [
					[ 'name' => esc_html__( 'Boxed', 'noisa-toolkit' ), 'value' => 'boxed' ],
					[ 'name' => esc_html__( 'Full width', 'noisa-toolkit' ), 'value' => 'full-width' ],
				],
				'desc'    => esc_html__( 'Select blog grid layout.', 'noisa-toolkit' ),
			],

		[
			'type' => 'tab_close',
		], 

		/* Import: Tab: Intro */
		noisa_toolkit_mb_common( 'intro_tab' ),

		/* Import: Facebook Sharing */
		noisa_toolkit_mb_common( 'facebook_sharing_tab' ),
		

	];

	/* Options Filter */
	if ( has_filter( 'rascals_mb_blog_grid_opts' ) ) {
		$meta_options = apply_filters( 'rascals_mb_blog_grid_opts', $meta_options );
	}

	/* Add class instance */
	$rascals_mb_template_blog_grid = new RascalsBox( $meta_options, $meta_info );


	/*
	==================================================
		Template: Blog List
	================================================== */

	/* Meta info */ 
	$meta_info = [
		'title'    => esc_html__( 'Blog Options', 'noisa-toolkit' ), 
		'id'       => 'rascals_mb_blog_list', 
		'page'     => [
			'page',
		], 
		'context'  => 'normal', 
		'priority' => 'high', 
		'callback' => '', 
		'template' => [ 
			'page-templates/blog.php',
		],
	];

	/* Box Filter */
	if ( has_filter( 'rascals_mb_blog_list_box' ) ) {
		$meta_info = apply_filters( 'rascals_mb_blog_list_box', $meta_info );
	}

	/* Meta options */
	$meta_options = [


		/*
		TAB: GENERAL
		-------------------------------- */
		[
			'name' => esc_html__( 'General', 'noisa-toolkit' ),
			'id'   => 'tab-general',
			'type' => 'tab_open',
		],

		// Limit
		[
			'name'      => esc_html__( 'Posts Per Page', 'noisa-toolkit' ),
			'id'        => '_limit',
			'type'      => 'range',
			'min'       => 1,
			'max'       => 100,
			'unit'      => esc_html__( 'items', 'noisa-toolkit' ),
			'separator' => true,
			'std'       => '8',
			'desc'      => esc_html__( 'Number of blog posts visible on page.', 'noisa-toolkit' ),
		],


		[
			'type' => 'tab_close',
		], 

		/* Import: Tab: Intro */
		noisa_toolkit_mb_common( 'intro_tab' ),

		/* Import: Layout Tab */ 
		noisa_toolkit_mb_common( 'layout_tab' ),

		/* Import: Facebook Sharing */
		noisa_toolkit_mb_common( 'facebook_sharing_tab' ),
		

	];

	/* Options Filter */
	if ( has_filter( 'rascals_mb_blog_list_opts' ) ) {
		$meta_options = apply_filters( 'rascals_mb_blog_list_opts', $meta_options );
	}

	/* Add class instance */
	$rascals_mb_template_blog_list = new RascalsBox( $meta_options, $meta_info );
}

return noisa_toolkit_mb_blog();
