<?php
/**
 * Rascals MetaBox
 *
 * Register Events Metabox
 *
 * @author Rascals Themes
 * @category Core
 * @package Noisa Toolkit
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed diCustomizer
}


/*
==================================================
	Metaboxes options
================================================== */
function noisa_toolkit_mb_events() {

	$rascals_mb = NoisaToolkit::getInstance()->metaboxes;


	/*
	==================================================
		Single Event 
	================================================== */

	/* Meta info */ 
	$meta_info = [
		'title'    => esc_html__( 'Event Options', 'noisa-toolkit' ), 
		'id'       => 'rascals_mb_event_single', 
		'page'     => [
			'noisa_events',
		], 
		'context'  => 'normal', 
		'priority' => 'high', 
		'callback' => '', 
		'template' => [ 
			'post',
		],
	];

	/* Box Filter */
	if ( has_filter( 'rascals_mb_event_single_box' ) ) {
		$meta_info = apply_filters( 'rascals_mb_event_single_box', $meta_info );
	}

	/* Meta options */
	$meta_options = [

		/*
		TAB: DATE
		-------------------------------- */
		[
			'name' => esc_html__( 'Date/Time', 'noisa-toolkit' ),
			'id'   => 'tab-date',
			'type' => 'tab_open',
		],

		[
			'name'      => esc_html__( 'Date', 'noisa-toolkit' ),
			'id'        => [
				[ 'id' => '_event_date_start', 'std' => date( 'Y-m-d' ) ],
				[ 'id' => '_event_date_end', 'std' => date( 'Y-m-d' ) ],
			],
			'type'      => 'date_range',
			'separator' => true,
			'desc'      => esc_html__( 'Enter the event date; eg 2010-09-11', 'noisa-toolkit' ),
		],
		[
			'name'      => esc_html__( 'Time', 'noisa-toolkit' ),
			'id'        => [
				[ 'id' => '_event_time_start', 'std' => '21:00' ],
				[ 'id' => '_event_time_end', 'std' => '00:00' ],
			],
			'type'      => 'time_range',
			'separator' => true,
			'desc'      => esc_html__( 'Enter the event time; eg 21:00 or 09:00 pm', 'noisa-toolkit' ),
		],
		[
			'name'      => esc_html__( 'Repeat', 'noisa-toolkit' ),
			'id'        => '_repeat_event',
			'type'      => 'select',
			'std'       => 'default',
			'options'   => [
				[ 'name' => esc_html__( 'None', 'noisa-toolkit' ), 'value' => 'none' ],
				[ 'name' => esc_html__( 'Weekly', 'noisa-toolkit' ), 'value' => 'weekly' ],
			],
			'separator' => true,
			'desc'      => esc_html__( 'Repeat event.', 'noisa-toolkit' ),
		],
		[
			'name'       => esc_html__( 'Every', 'noisa-toolkit' ),
			'id'         => '_every',
			'type'       => 'range',
			'std'        => '1',
			'min'        => 1,
			'max'        => 52,
			'unit'       => esc_html__( 'week(s)', 'noisa-toolkit' ),
			'separator'  => true,
			'desc'       => esc_html__( 'Repeat event every week(s).', 'noisa-toolkit' ),
			'dependency' => [
				'element' => '_repeat_event',
				'value'   => [ 'weekly' ],
			],
		],
		[
			'name'       => esc_html__( 'Day(s)', 'noisa-toolkit' ),
			'id'         => '_weekly_days',
			'type'       => 'multiselect',
			'std'        => [ 'friday' ],
			'options'    => [
				[ 'name' => esc_html__( 'Monday', 'noisa-toolkit' ), 'value' => 'monday' ],
				[ 'name' => esc_html__( 'Tuesday', 'noisa-toolkit' ), 'value' => 'tuesday' ],
				[ 'name' => esc_html__( 'Wednesday', 'noisa-toolkit' ), 'value' => 'wednesday' ],
				[ 'name' => esc_html__( 'Thursday', 'noisa-toolkit' ), 'value' => 'thursday' ],
				[ 'name' => esc_html__( 'Friday', 'noisa-toolkit' ), 'value' => 'friday' ],
				[ 'name' => esc_html__( 'Saturday', 'noisa-toolkit' ), 'value' => 'saturday' ],
				[ 'name' => esc_html__( 'Sunday', 'noisa-toolkit' ), 'value' => 'sunday' ],
			],
			'separator'  => true,
			'desc'       => esc_html__( 'Please use the CTRL key (PC) or COMMAND key (Mac) to select multiple items.', 'noisa-toolkit' ),
			'dependency' => [
				'element' => '_repeat_event',
				'value'   => [ 'weekly' ],
			],
		],

		[
			'type' => 'tab_close',
		],


		/* Import: Tab: Intro */
		noisa_toolkit_mb_common( 'intro_tab' ),

		/* Import: Layout Tab */ 
		noisa_toolkit_mb_common( 'layout_tab' ),

		/* Import: Facebook Sharing */
		noisa_toolkit_mb_common( 'facebook_sharing_tab' ),
		
	];

	/* Options Filter */
	if ( has_filter( 'rascals_mb_event_single_opts' ) ) {
		$meta_options = apply_filters( 'rascals_mb_event_single_opts', $meta_options );
	}

	/* Add class instance */
	$rascals_mb_single_event = new RascalsBox( $meta_options, $meta_info );


	/*
	==================================================
		Template: Events Grid
	================================================== */

	/* Meta info */ 
	$meta_info = [
		'title'    => esc_html__( 'Events Options', 'noisa-toolkit' ), 
		'id'       => 'rascals_mb_events_grid', 
		'page'     => [
			'page',
		], 
		'context'  => 'normal', 
		'priority' => 'high', 
		'callback' => '', 
		'template' => [ 
			'page-templates/events-grid.php',
		],
	];

	/* Box Filter */
	if ( has_filter( 'rascals_mb_events_grid_box' ) ) {
		$meta_info = apply_filters( 'rascals_mb_events_grid_box', $meta_info );
	}

	/* Meta options */
	$meta_options = [


		/*
		TAB: GENERAL
		-------------------------------- */
		[
			'name' => esc_html__( 'General', 'noisa-toolkit' ),
			'id'   => 'tab-general',
			'type' => 'tab_open',
		],

		/* Type */
		[
			'name'      => esc_html__( 'Events Type', 'noisa-toolkit' ),
			'id'        => '_event_type',
			'type'      => 'select',
			'std'       => 'future-events',
			'separator' => true,
			'options'   => [
				[ 'name' => esc_html__( 'Future events', 'noisa-toolkit' ), 'value' => 'future-events' ],
				[ 'name' => esc_html__( 'Past events', 'noisa-toolkit' ), 'value' => 'past-events' ],
				[ 'name' => esc_html__( 'All events', 'noisa-toolkit' ), 'value' => 'all-events' ],
			],
			'desc'      => esc_html__( 'Choose the events type.', 'noisa-toolkit' ),
		],

		/* Limit */
		[
			'name'      => esc_html__( 'Events Per Page', 'noisa-toolkit' ),
			'id'        => '_limit',
			'type'      => 'range',
			'min'       => 1,
			'max'       => 100,
			'unit'      => esc_html__( 'event(s)', 'noisa-toolkit' ),
			'std'       => '8',
			'separator' => true,
			'desc'      => esc_html__( 'Number of events visible on page.', 'noisa-toolkit' ),
		],

		/* Gap */ 
		[
			'name'      => esc_html__( 'Thumbnails Gap', 'noisa-toolkit' ),
			'id'        => '_gap',
			'type'      => 'select',
			'std'       => 'no-gap',
			'options'   => [
				[ 'name' => esc_html__( 'Small Gap', 'noisa-toolkit' ), 'value' => 'no-gap' ],
				[ 'name' => esc_html__( 'Medium gap', 'noisa-toolkit' ), 'value' => 'medium-gap' ],
			],
			'separator' => true,
			'desc'      => esc_html__( 'Display gap between thumbnails.', 'noisa-toolkit' ),
		],

		/* Grid layout */ 
			[
				'name'      => esc_html__( 'Grid Layout', 'noisa-toolkit' ),
				'id'        => '_events_layout',
				'type'      => 'select',
				'std'       => 'boxed',
				'options'   => [
					[ 'name' => esc_html__( 'Boxed', 'noisa-toolkit' ), 'value' => 'boxed' ],
					[ 'name' => esc_html__( 'Full width', 'noisa-toolkit' ), 'value' => 'full-width' ],
				],
				'separator' => true,
				'desc'      => esc_html__( 'Select grid layout.', 'noisa-toolkit' ),
			],

		/* Thumbnail */ 
			[
				'name'      => esc_html__( 'Thumbnail Style', 'noisa-toolkit' ),
				'id'        => '_event_thumb_style',
				'type'      => 'select',
				'std'       => 'default-style',
				'options'   => [
					[ 'name' => esc_html__( 'Default', 'noisa-toolkit' ), 'value' => 'default-style' ],
					[ 'name' => esc_html__( 'Inverted', 'noisa-toolkit' ), 'value' => 'inverted' ],
				],
				'separator' => true,
				'desc'      => esc_html__( 'Select thumb style.', 'noisa-toolkit' ),
			],

		/* Filters */
		[
			'name'       => esc_html__( 'Filters', 'noisa-toolkit' ),
			'id'         => '_filters',
			'type'       => 'multiselect',
			'std'        => [ 'artists', 'locations', 'categories' ],
			'save_empty' => true,
			'options'    => [
				[ 'name' => esc_html__( 'Artists', 'noisa-toolkit' ), 'value' => 'artists' ],
				[ 'name' => esc_html__( 'Locations', 'noisa-toolkit' ), 'value' => 'locations' ],
				[ 'name' => esc_html__( 'Categories', 'noisa-toolkit' ), 'value' => 'categories' ],
			],
			'separator'  => true,
			'desc'       => esc_html__( 'Please use the CTRL key (PC) or COMMAND key (Mac) to select multiple filters.', 'noisa-toolkit' ),
		],

		[
			'type' => 'tab_close',
		],


		/* Import: Tab: Intro */
		noisa_toolkit_mb_common( 'intro_tab' ),

		/* Import: Facebook Sharing */
		noisa_toolkit_mb_common( 'facebook_sharing_tab' ),

		

	];

	/* Options Filter */
	if ( has_filter( 'rascals_mb_events_grid_opts' ) ) {
		$meta_options = apply_filters( 'rascals_mb_events_grid_opts', $meta_options );
	}

	/* Add class instance */
	$rascals_mb_template_events_grid = new RascalsBox( $meta_options, $meta_info );


	/*
	==================================================
		Template: Events List
	================================================== */

	/* Meta info */ 
	$meta_info = [
		'title'    => esc_html__( 'Events Options', 'noisa-toolkit' ), 
		'id'       => 'rascals_mb_events_list', 
		'page'     => [
			'page',
		], 
		'context'  => 'normal', 
		'priority' => 'high', 
		'callback' => '', 
		'template' => [ 
			'page-templates/events-list.php',
		],
	];

	/* Box Filter */
	if ( has_filter( 'rascals_mb_events_list_box' ) ) {
		$meta_info = apply_filters( 'rascals_mb_events_list_box', $meta_info );
	}

	/* Meta options */
	$meta_options = [


		/*
		TAB: GENERAL
		-------------------------------- */
		[
			'name' => esc_html__( 'General', 'noisa-toolkit' ),
			'id'   => 'tab-general',
			'type' => 'tab_open',
		],

		// Type
		[
			'name'      => esc_html__( 'Events Type', 'noisa-toolkit' ),
			'id'        => '_event_type',
			'type'      => 'select',
			'std'       => 'future-events',
				
			'options'   => [
				[ 'name' => esc_html__( 'Future events', 'noisa-toolkit' ), 'value' => 'future-events' ],
				[ 'name' => esc_html__( 'Past events', 'noisa-toolkit' ), 'value' => 'past-events' ],
				[ 'name' => esc_html__( 'All events', 'noisa-toolkit' ), 'value' => 'all-events' ],
			],
			'separator' => true,
			'desc'      => esc_html__( 'Choose the events type.', 'noisa-toolkit' ),
		],

		// Limit
		[
			'name'      => esc_html__( 'Events Per Page', 'noisa-toolkit' ),
			'id'        => '_limit',
			'type'      => 'range',
			'min'       => 1,
			'max'       => 100,
			'unit'      => esc_html__( 'items', 'noisa-toolkit' ),
			'std'       => '8',
			'separator' => true,
			'desc'      => esc_html__( 'Number of events visible on page.', 'noisa-toolkit' ),
		],

		/* Filters */
		[
			'name'       => esc_html__( 'Filters', 'noisa-toolkit' ),
			'id'         => '_filters',
			'type'       => 'multiselect',
			'std'        => [ 'artists', 'locations', 'categories' ],
			'save_empty' => true,
			'options'    => [
				[ 'name' => esc_html__( 'Artists', 'noisa-toolkit' ), 'value' => 'artists' ],
				[ 'name' => esc_html__( 'Locations', 'noisa-toolkit' ), 'value' => 'locations' ],
				[ 'name' => esc_html__( 'Categories', 'noisa-toolkit' ), 'value' => 'categories' ],
			],
			'separator'  => true,
			'desc'       => esc_html__( 'Please use the CTRL key (PC) or COMMAND key (Mac) to select multiple filters.', 'noisa-toolkit' ),
		],

			
		[
			'type' => 'tab_close',
		],


		/* Import: Tab: Intro */
		noisa_toolkit_mb_common( 'intro_tab' ),

		/* Import: Facebook Sharing */
		noisa_toolkit_mb_common( 'facebook_sharing_tab' ),
		

	];

	/* Options Filter */
	if ( has_filter( 'rascals_mb_events_list_opts' ) ) {
		$meta_options = apply_filters( 'rascals_mb_events_list_opts', $meta_options );
	}

	/* Add class instance */
	$rascals_mb_template_events_list = new RascalsBox( $meta_options, $meta_info );
}

return noisa_toolkit_mb_events();
