<?php
/**
 * Rascals MetaBox
 *
 * Register Gallery Metabox
 *
 * @author Rascals Themes
 * @category Core
 * @package Noisa Toolkit
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/*
==================================================
	Metaboxes options
================================================== */
function noisa_toolkit_mb_gallery() {

	$rascals_mb = NoisaToolkit::getInstance()->metaboxes;


	/*
	==================================================
		Single Album
	================================================== */

	/* Meta info */ 
	$meta_info = [
		'title'    => esc_html__( 'Album Options', 'noisa-toolkit' ), 
		'id'       => 'rascals_mb_gallery_box', 
		'page'     => [
			'noisa_gallery',
		], 
		'context'  => 'normal', 
		'priority' => 'high', 
		'callback' => '', 
		'template' => [ 
			'post',
		],
	];

	/* Box Filter */
	if ( has_filter( 'rascals_mb_gallery_box' ) ) {
		$meta_info = apply_filters( 'rascals_mb_gallery_box', $meta_info );
	}

	/* Meta options */
	$meta_options = [


		/*
		TAB: IMAGES
		-------------------------------- */
		[
			'name' => esc_html__( 'Images', 'noisa-toolkit' ),
			'id'   => 'tab-images',
			'type' => 'tab_open',
		],

		[ 
			'id'         => '_gallery_ids',
			'type'       => 'media_manager',
			'media_type' => 'images', // images / audio / slider
			'layout'     => 'grid', // grid, list
			'buttons'    => [
				[
					'type'  => 'explorer', // explorer, custom
					'label' => esc_html__( 'Add Images', 'noisa-toolkit' ),
					'title' => esc_html__( 'Add images from media libary', 'noisa-toolkit' ),
					'color' => 'blue',
				],
			],
			'msg_text'   => esc_html__( 'Currently you don\'t have any images, you can add them by clicking on the button below.', 'noisa-toolkit' ),
			'desc'       => esc_html__( 'Hold the CTRL key (PC) or COMMAND key (Mac) and click the items in a list to choose them. Click all the items you want to select. They don’t have to be next to each other.
				Click any item again to deselect it, e.g. if you have made a mistake. Remember to keep the CTRL or COMMAND key pressed.', 'noisa-toolkit' ),
		],

		// Limit
		[
			'name'      => esc_html__( 'Images Per Page', 'noisa-toolkit' ),
			'id'        => '_limit',
			'type'      => 'range',
			'min'       => 1,
			'max'       => 200,
			'unit'      => esc_html__( 'images', 'noisa-toolkit' ),
			'std'       => '8',
			'separator' => true,
			'desc'      => esc_html__( 'Number of images limit on page.', 'noisa-toolkit' ),
		],

		[
			'type' => 'tab_close',
		],

		/* Import: Tab: Intro */
		noisa_toolkit_mb_common( 'intro_tab' ),

		/* Import: Facebook Sharing */
		noisa_toolkit_mb_common( 'facebook_sharing_tab' ),

	];

	/* Options Filter */
	if ( has_filter( 'rascals_mb_gallery_opts' ) ) {
		$meta_options = apply_filters( 'rascals_mb_gallery_opts', $meta_options );
	}

	/* Add class instance */
	$rascals_mb_gallery = new RascalsBox( $meta_options, $meta_info );


	/*
	==================================================
		Gallery Grid Template
	================================================== */

	/* Meta info */ 
	$meta_info = [
		'title'    => esc_html__( 'Gallery Options', 'noisa-toolkit' ), 
		'id'       => 'rascals_mb_gallery_template', 
		'page'     => [
			'page',
		], 
		'context'  => 'normal', 
		'priority' => 'high', 
		'callback' => '', 
		'template' => [ 
			'page-templates/gallery.php',
		],
	];

	/* Box Filter */
	if ( has_filter( 'rascals_mb_gallery_template_box' ) ) {
		$meta_info = apply_filters( 'rascals_mb_gallery_template_box', $meta_info );
	}

	/* Meta options */
	$meta_options = [
		

		/*
		TAB: GENERAL
		-------------------------------- */
		[
			'name' => esc_html__( 'General', 'noisa-toolkit' ),
			'id'   => 'tab-general',
			'type' => 'tab_open',
		],

		/* Limit */ 
		[
			'name'      => esc_html__( 'Albums Per Page', 'noisa-toolkit' ),
			'id'        => '_limit',
			'type'      => 'range',
			'std'       => '8',
			'min'       => 1,
			'max'       => 100,
			'unit'      => esc_html__( 'album(s)', 'noisa-toolkit' ),
			'separator' => true,
			'desc'      => esc_html__( 'Number of albums visible on page.', 'noisa-toolkit' ),
		],
			
		/* Gap */ 
		[
			'name'      => esc_html__( 'Thumbnails Gap', 'noisa-toolkit' ),
			'id'        => '_gap',
			'type'      => 'select',
			'std'       => 'no-gap',
			'options'   => [
				[ 'name' => esc_html__( 'Small Gap', 'noisa-toolkit' ), 'value' => 'no-gap' ],
				[ 'name' => esc_html__( 'Medium gap', 'noisa-toolkit' ), 'value' => 'medium-gap' ],
			],
			'separator' => true,
			'desc'      => esc_html__( 'Display gap between thumbnails.', 'noisa-toolkit' ),
		],

		/* Grid layout */ 
			[
				'name'      => esc_html__( 'Grid Layout', 'noisa-toolkit' ),
				'id'        => '_gallery_layout',
				'type'      => 'select',
				'std'       => 'boxed',
				'options'   => [
					[ 'name' => esc_html__( 'Boxed', 'noisa-toolkit' ), 'value' => 'boxed' ],
					[ 'name' => esc_html__( 'Full width', 'noisa-toolkit' ), 'value' => 'full-width' ],
				],
				'separator' => true,
				'desc'      => esc_html__( 'Select grid layout.', 'noisa-toolkit' ),
			],

		/* Filters */ 
		[
			'name'       => esc_html__( 'Filters', 'noisa-toolkit' ),
			'id'         => '_filters',
			'type'       => 'multiselect',
			'std'        => [ 'genres', 'categories' ],
			'save_empty' => true,
			'options'    => [
				[ 'name' => esc_html__( 'Artists', 'noisa-toolkit' ), 'value' => 'artists' ],
				[ 'name' => esc_html__( 'Categories', 'noisa-toolkit' ), 'value' => 'categories' ],
			],
			'separator'  => true,
			'desc'       => esc_html__( 'Please use the CTRL key (PC) or COMMAND key (Mac) to select multiple filters.', 'noisa-toolkit' ),
		],


		[
			'type' => 'tab_close',
		],


		/* Import: Tab: Intro */
		noisa_toolkit_mb_common( 'intro_tab' ),

		/* Import: Facebook Sharing */
		noisa_toolkit_mb_common( 'facebook_sharing_tab' ),

	];

	/* Options Filter */
	if ( has_filter( 'rascals_mb_gallery_template_opts' ) ) {
		$meta_options = apply_filters( 'rascals_mb_gallery_template_opts', $meta_options );
	}

	/* Add class instance */
	$rascals_mb_gallery_template = new RascalsBox( $meta_options, $meta_info );
}

return noisa_toolkit_mb_gallery();
