<?php
/**
 * Rascals MetaBox
 *
 * Register Post Metabox
 *
 * @author Rascals Themes
 * @category Core
 * @package Noisa Toolkit
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed diCustomizer
}


/*
==================================================
	Metaboxes options
================================================== */
function noisa_toolkit_mb_post() {

	$rascals_mb = NoisaToolkit::getInstance()->metaboxes;


	/*
	==================================================
		Single Post 
	================================================== */

	/* Meta info */ 
	$meta_info = [
		'title'    => esc_html__( 'Post Options', 'noisa-toolkit' ), 
		'id'       => 'rascals_mb_post', 
		'page'     => [
			'post',
		], 
		'context'  => 'normal', 
		'priority' => 'high', 
		'callback' => '', 
		'template' => [ 
			'default',
		],
	];

	/* Box Filter */
	if ( has_filter( 'rascals_mb_post_box' ) ) {
		$meta_info = apply_filters( 'rascals_mb_post_box', $meta_info );
	}

	/* Meta options */
	$meta_options = [


		/*
		TAB: POST HEADER
		-------------------------------- */
		[
			'name' => esc_html__( 'Post Format', 'noisa-toolkit' ),
			'id'   => 'tab-post-formats',
			'type' => 'tab_open',
		],

		/* Post Format */ 
		[
			'name'      => esc_html__( 'Type', 'noisa-toolkit' ),
			'id'        => '_post_format',
			'type'      => 'select',
			'std'       => 'pf_standard',
			'options'   => [
				[ 'name' => esc_html__( 'Standard', 'noisa-toolkit' ), 'value' => 'pf_standard' ],
				[ 'name' => esc_html__( 'Image', 'noisa-toolkit' ), 'value' => 'pf_image' ],
				[ 'name' => esc_html__( 'Gallery', 'noisa-toolkit' ), 'value' => 'pf_gallery' ],
				[ 'name' => esc_html__( 'Video', 'noisa-toolkit' ), 'value' => 'pf_video' ],
				[ 'name' => esc_html__( 'Quote', 'noisa-toolkit' ), 'value' => 'pf_quote' ],
				[ 'name' => esc_html__( 'Link', 'noisa-toolkit' ), 'value' => 'pf_link' ],
				[ 'name' => esc_html__( 'Audio - Soundcloud', 'noisa-toolkit' ), 'value' => 'pf_audio_sc' ],
				[ 'name' => esc_html__( 'Audio - Album', 'noisa-toolkit' ), 'value' => 'pf_audio_album' ],
				[ 'name' => esc_html__( 'Link', 'noisa-toolkit' ), 'value' => 'pf_link' ],
			],
			'separator' => true,
			'desc'      => esc_html__( 'Select post format type.', 'noisa-toolkit' ),
		], 

		/* Gallery Slider */ 
			[
				'name'       => esc_html__( 'Gallery Slider', 'noisa-toolkit' ),
				'id'         => '_gallery_slider_id',
				'type'       => 'select_array',
				'std'        => '',
				'options'    => $rascals_mb->getSlider( 'noisa_slider' ),
				'desc'       => esc_html__( 'Select slider; If there are no sliders available, then you can add a slider and images using Slider custom posts menu on the left. NOTE: Only working with GALLERY post format.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_gallery' ],
				],
			],

		/* Youtube */ 
			[
				'name'       => esc_html__( 'Video YouTube', 'noisa-toolkit' ),
				'id'         => '_video_yt_id',
				'type'       => 'text',
				'std'        => '',
				'desc'       => esc_html__( 'Add YouTube movie ID. NOTE: Only working with VIDEO post format.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_video' ],
				],
			],

		/* Vimeo */ 
			[
				'name'       => esc_html__( 'Video Vimeo', 'noisa-toolkit' ),
				'id'         => '_video_vimeo_id',
				'type'       => 'text',
				'std'        => '',
				'desc'       => esc_html__( 'Add Vimeo movie ID. NOTE: Only working with VIDEO post format.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_video' ],
				],
			],

		/* Audio Soundcloud */ 
			[
				'name'       => esc_html__( 'Soundcloud Audio', 'noisa-toolkit' ),
				'id'         => '_sc_iframe',
				'type'       => 'textarea',
				'std'        => '',
				'tinymce'    => 'false',
				'height'     => '100',
				'desc'       => esc_html__( 'Paste iframe code from soundcloud track. NOTE: Only working with AUDIO post format.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_audio_sc' ],
				],
			],

		/* Audio Single Album */ 
			[
				'name'       => esc_html__( 'Audio Album', 'noisa-toolkit' ),
				'id'         => '_pf_tracks_id',
				'type'       => 'select_array',
				'std'        => '',
				'options'    => $rascals_mb->getTracks( 'noisa_tracks' ),
				'desc'       => esc_html__( 'Select your tracks; If there are no tracks available, then you can add a audio tracks using TRACKS custom posts menu on the left.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_audio_album' ],
				],
			],

		/* Title */ 
			[
				'name'       => esc_html__( 'Title', 'noisa-toolkit' ),
				'id'         => '_album_title',
				'type'       => 'text',
				'std'        => '',
				'desc'       => esc_html__( 'Album title.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_audio_album' ],
				],
			],

		/* Artists */ 
			[
				'name'       => esc_html__( 'Artists', 'noisa-toolkit' ),
				'id'         => '_album_artists',
				'type'       => 'text',
				'std'        => '',
				'desc'       => esc_html__( 'Album Artists.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_audio_album' ],
				],
			],

		/* Album Image */ 
			[
				'name'       => esc_html__( 'Album Image', 'noisa-toolkit' ),
				'id'         => '_album_image', 
				'type'       => 'add_image',
				'std'        => '',
				'source'     => 'media_libary', // all, media_libary, external_link
				'desc'       => esc_html__( 'Album cover.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_audio_album' ],
				],
			],

		/* Quote */ 
			[
				'name'       => esc_html__( 'Quote Text', 'noisa-toolkit' ),
				'id'         => '_quote_text',
				'type'       => 'textarea',
				'std'        => '',
				'tinymce'    => 'false',
				'height'     => '100',
				'desc'       => esc_html__( 'Quote text.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_quote' ],
				],
			],

		/* Quote Author */ 
			[
				'name'       => esc_html__( 'Quote Author', 'noisa-toolkit' ),
				'id'         => '_quote_author',
				'type'       => 'text',
				'std'        => '',
				'desc'       => esc_html__( 'Quote text.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_quote' ],
				],
			],

		/* Quote Link */ 
			[
				'name'       => esc_html__( 'Quote Link', 'noisa-toolkit' ),
				'id'         => '_quote_link',
				'type'       => 'text',
				'std'        => '',
				'desc'       => esc_html__( 'Quote link.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_quote' ],
				],
			],

		/* Link Title */ 
			[
				'name'       => esc_html__( 'Link Title', 'noisa-toolkit' ),
				'id'         => '_link_title',
				'type'       => 'text',
				'std'        => '',
				'desc'       => esc_html__( 'Link title.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_link' ],
				],
			],

		/* Link URL */ 
			[
				'name'       => esc_html__( 'Link URL', 'noisa-toolkit' ),
				'id'         => '_link_url',
				'type'       => 'text',
				'std'        => '',
				'desc'       => esc_html__( 'Link URL.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_link' ],
				],
			],

		/* Open in New Window? */ 
			[
				'name'       => esc_html__( 'Open in New Window?', 'noisa-toolkit' ),
				'id'         => '_link_new_window',
				'type'       => 'switch_button',
				'std'        => '',
				'desc'       => esc_html__( 'Open link in new window.', 'noisa-toolkit' ),
				'dependency' => [
					'element' => '_post_format',
					'value'   => [ 'pf_link' ],
				],
			],
			
		[
			'type' => 'tab_close',
		],


		/* Import: Tab: Intro */
		noisa_toolkit_mb_common( 'intro_tab' ),

		/* Import: Layout Tab */ 
		noisa_toolkit_mb_common( 'layout_tab' ),

		/* Import: Facebook Sharing */
		noisa_toolkit_mb_common( 'facebook_sharing_tab' ),
		

	];

	/* Options Filter */
	if ( has_filter( 'rascals_mb_post_opts' ) ) {
		$meta_options = apply_filters( 'rascals_mb_post_opts', $meta_options );
	}

	/* Add class instance */
	return new RascalsBox( $meta_options, $meta_info );
}

return noisa_toolkit_mb_post();
