<?php
/**
 * Rascals MetaBox
 *
 * Register Slider Metabox
 *
 * @author Rascals Themes
 * @category Core
 * @package Noisa Toolkit
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed diCustomizer
}


/*
==================================================
	Metaboxes options
================================================== */
function noisa_toolkit_mb_slider() {

	$rascals_mb = NoisaToolkit::getInstance()->metaboxes;


	/*
	==================================================
		Single Slider 
	================================================== */

	/* Meta info */ 
	$meta_info = [
		'title'    => esc_html__( 'Slider Options', 'noisa-toolkit' ), 
		'id'       => 'rascals_mb_slider', 
		'page'     => [
			'noisa_slider',
		], 
		'context'  => 'normal', 
		'priority' => 'high', 
		'callback' => '', 
		'template' => [ 
			'post',
		],
	];

	/* Box Filter */
	if ( has_filter( 'rascals_mb_slider_box' ) ) {
		$meta_info = apply_filters( 'rascals_mb_slider_box', $meta_info );
	}

	/* Meta options */
	$meta_options = [


		/*
		TAB: SLIDER IMAGES
		-------------------------------- */
		[
			'name' => esc_html__( 'Images', 'noisa-toolkit' ),
			'id'   => 'tab-images',
			'type' => 'tab_open',
		],

		/* Images */
		[ 
			'id'         => '_custom_slider',
			'type'       => 'media_manager',
			'media_type' => 'slider', // images / audio /slider
			'layout'     => 'grid', // grid, list
			'buttons'    => [
				[
					'type'  => 'explorer', // explorer, custom
					'label' => esc_html__( 'Add Images', 'noisa-toolkit' ),
					'title' => esc_html__( 'Add images from media libary', 'noisa-toolkit' ),
					'color' => 'blue',
				],
			],
			'msg_text'   => esc_html__( 'Currently you don\'t have any images, you can add them by clicking on the button below.', 'noisa-toolkit' ),
			'desc'       => esc_html__( 'Hold the CTRL key (PC) or COMMAND key (Mac) and click the items in a list to choose them. Click all the items you want to select. They don’t have to be next to each other.
				Click any item again to deselect it, e.g. if you have made a mistake. Remember to keep the CTRL or COMMAND key pressed.', 'noisa-toolkit' ),
		],
			
		[
			'type' => 'tab_close',
		],

		/*
		TAB: SLIDER OPTIONS
		-------------------------------- */
		[
			'name' => esc_html__( 'Options', 'noisa-toolkit' ),
			'id'   => 'tab-options',
			'type' => 'tab_open',
		],

		/* Navigation */ 
		[
			'name'      => esc_html__( 'Navigation', 'noisa-toolkit' ),
			'id'        => '_slider_nav',
			'type'      => 'switch_button',
			'std'       => 'on',
			'options'   => [
				[ 'name' => 'On', 'value' => 'on' ], // ON
				[ 'name' => 'Off', 'value' => 'off' ], // OFF
			],
			'separator' => true,
			'desc'      => esc_html__( 'If this opion is on, then you should see the slider navigation.', 'noisa-toolkit' ),
		],  

		/* Pagination */ 
		[
			'name'      => esc_html__( 'Pagination', 'noisa-toolkit' ),
			'id'        => '_slider_pagination',
			'type'      => 'switch_button',
			'std'       => 'on',
			'options'   => [
				[ 'name' => 'On', 'value' => 'on' ], // ON
				[ 'name' => 'Off', 'value' => 'off' ], // OFF
			],
			'separator' => true,
			'desc'      => esc_html__( 'If this opion is on, then you should see the slider pagination.', 'noisa-toolkit' ),
		],  

		/* Animation Speed */ 
		[
			'name'      => esc_html__( 'Animation Speed', 'noisa-plugin' ),
			'id'        => '_slider_speed',
			'type'      => 'range',
			'max'       => '2000',
			'min'       => '200',
			'unit'      => esc_html__( 'ms', 'noisa-toolkit' ),
			'step'      => '1',
			'std'       => '500',
			'separator' => true,
			'desc'      => esc_html__( 'Slider animation speed.', 'noisa-plugin' ),
		], 

		/* Pause Time */ 
		[
			'name'      => esc_html__( 'Pause Time', 'noisa-plugin' ),
			'id'        => '_slider_pause_time',
			'type'      => 'range',
			'max'       => '20000',
			'min'       => '0',
			'unit'      => esc_html__( 'ms', 'noisa-toolkit' ),
			'step'      => '1',
			'std'       => '3000',
			'separator' => true,
			'desc'      => esc_html__( 'Determines how long each slide will be shown.  NOTE: Value "0" disable slider timer.', 'noisa-plugin' ),
		], 
				
			
		[
			'type' => 'tab_close',
		],

		

	];

	/* Options Filter */
	if ( has_filter( 'rascals_mb_slider_opts' ) ) {
		$meta_options = apply_filters( 'rascals_mb_slider_opts', $meta_options );
	}

	/* Add class instance */
	return new RascalsBox( $meta_options, $meta_info );
}

return noisa_toolkit_mb_slider();
