<?php
/**
 * Rascals Register Gallery
 *
 * @author Rascals Themes
 * @category Core
 * @package Noisa Toolkit
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


class RascalsRegisterGallery extends RascalsCPT {

	/**
	 * Instance of RascalsCPT 
	 *
	 * @var class
	 */
	private $cpt;

	/*
	Public variables
	 */
	public $post_name = 'noisa_gallery';
	public $icon      = 'dashicons-camera';
	public $supports  = [ 'title', 'editor', 'excerpt', 'thumbnail', 'comments', 'custom-fields' ];

	/**
	 * Rascals CPT Constructor.
	 *
	 * @return void
	 */
	public function __construct() {
		$this->init();
	}

	/**
	 * Initialize class
	 *
	 * @return void
	 */
	public function init() {
		add_action( 'init', [ $this, 'regsiterPostType' ], 0 );
		add_action( 'parse_query', [ $this, 'disableCanonicalRedirect' ] );
	}


	/**
	 * Pagination images fix
	 *
	 * @param  $query
	 * @return void
	 */
	public function disableCanonicalRedirect( $query ) {
	
		if ( isset( $query->query_vars['post_type'] ) && 'noisa_gallery' == $query->query_vars['post_type'] ) {
			remove_filter( 'template_redirect', 'redirect_canonical' );
		}
	}


	/**
	 * Register Post Type
	 *
	 * @return void
	 */
	public function regsiterPostType() {

		// Init Toolkit
		$toolkit = noisaToolkit();

		// Class arguments 
		$args = [ 
			'post_name' => $this->post_name, 
			'sortable'  => false,
		];

		// Post arguments
		$post_options = [
			'labels'            => [
				'name'               => esc_html__( 'Gallery', 'noisa-toolkit' ),
				'singular_name'      => esc_html__( 'Gallery', 'noisa-toolkit' ),
				'add_new'            => esc_html__( 'Add New', 'noisa-toolkit' ),
				'add_new_item'       => esc_html__( 'Add New Gallery', 'noisa-toolkit' ),
				'edit_item'          => esc_html__( 'Edit Gallery', 'noisa-toolkit' ),
				'new_item'           => esc_html__( 'New Gallery', 'noisa-toolkit' ),
				'view_item'          => esc_html__( 'View Gallery', 'noisa-toolkit' ),
				'search_items'       => esc_html__( 'Search', 'noisa-toolkit' ),
				'not_found'          => esc_html__( 'No gallery found', 'noisa-toolkit' ),
				'not_found_in_trash' => esc_html__( 'No gallery found in Trash', 'noisa-toolkit' ), 
				'parent_item_colon'  => '',
			],
			'public'            => true,
			'show_ui'           => true,
			'show_in_nav_menus' => true,
			'capability_type'   => 'post',
			'hierarchical'      => false,
			'rewrite'           => [
				'slug'       => $toolkit->get_theme_option( 'gallery_slug', 'gallery' ),
				'with_front' => false,
			],
			'supports'          => $this->supports,
			'menu_icon'         => $this->icon,
		];

		// Register taxonomy
		register_taxonomy( 'noisa_gallery_cats', [ $this->post_name ], [
			'hierarchical'   => true,
			'label'          => esc_html__( 'Categories', 'noisa-toolkit' ),
			'singular_label' => esc_html__( 'Category', 'noisa-toolkit' ),
			'query_var'      => true,
			'show_in_rest'   => true,
			'rewrite'        => [
				'slug'       => $toolkit->get_theme_option( 'gallery_cat_slug', 'gallery-category' ),
				'with_front' => false,
			],
		]);

		// Register taxonomy 2
		register_taxonomy( 'noisa_gallery_artists', [ $this->post_name ], [
			'hierarchical'   => true,
			'label'          => esc_html__( 'Artists', 'noisa-toolkit' ),
			'singular_label' => esc_html__( 'Artist', 'noisa-toolkit' ),
			'query_var'      => true,
			'show_in_rest'   => true,
			'rewrite'        => [
				'slug'       => $toolkit->get_theme_option( 'gallery_artists_slug', 'gallery-artist' ),
				'with_front' => false,
			],
		]);


		// Add Class instance
		$this->cpt = new RascalsCPT( $args, $post_options );

		// Add columns filter
		$columns_filter_args = [
			'post_name'    => $this->post_name,
			'filter_label' => esc_html__( 'Filter', 'noisa-toolkit' ),
			'filters'      => [
				'noisa_gallery_cats',
				'noisa_gallery_artists',
			],
			'extra_cols'   => [
				'cb'      => '<input type="checkbox" />',
				'title'   => esc_html__( 'Title', 'noisa-toolkit' ),
				'date'    => esc_html__( 'Date', 'noisa-toolkit' ),
				'preview' => esc_html__( 'Preview', 'noisa-toolkit' ),
			],
		];

		$this->cpt->addAdminColumns( $columns_filter_args );
	}
}
