<?php
/**
 * Rascals Register Releases
 *
 * @author Rascals Themes
 * @category Core
 * @package Noisa Toolkit
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


class RascalsRegisterReleases extends RascalsCPT {

	/**
	 * Instance of RascalsCPT 
	 *
	 * @var class
	 */
	private $cpt;

	/*
	Public variables
	 */
	public $post_name = 'noisa_releases';
	public $icon      = 'dashicons-album';
	public $supports  = [ 'title', 'editor', 'excerpt', 'thumbnail', 'comments', 'custom-fields' ];

	/**
	 * Rascals CPT Constructor.
	 *
	 * @return void
	 */
	public function __construct() {
		$this->init();
	}

	/**
	 * Initialize class
	 *
	 * @return void
	 */
	public function init() {
		add_action( 'init', [ $this, 'regsiterPostType' ], 0 );
	}

	/**
	 * Register Post Type
	 *
	 * @return void
	 */
	public function regsiterPostType() {

		// Class arguments 
		$args = [ 
			'post_name' => $this->post_name, 
			'sortable'  => true,
		];

		// Post arguments
		$post_options = [
			'labels'            => [
				'name'               => esc_html__( 'Releases', 'noisa-toolkit' ),
				'singular_name'      => esc_html__( 'Releases', 'noisa-toolkit' ),
				'add_new'            => esc_html__( 'Add New', 'noisa-toolkit' ),
				'add_new_item'       => esc_html__( 'Add New Release', 'noisa-toolkit' ),
				'edit_item'          => esc_html__( 'Edit Release', 'noisa-toolkit' ),
				'new_item'           => esc_html__( 'New Release', 'noisa-toolkit' ),
				'view_item'          => esc_html__( 'View Release', 'noisa-toolkit' ),
				'search_items'       => esc_html__( 'Search Releases', 'noisa-toolkit' ),
				'not_found'          => esc_html__( 'No releases found', 'noisa-toolkit' ),
				'not_found_in_trash' => esc_html__( 'No releases found in Trash', 'noisa-toolkit' ), 
				'parent_item_colon'  => '',
			],
			'public'            => true,
			'show_ui'           => true,
			'show_in_nav_menus' => true,
			'capability_type'   => 'post',
			'hierarchical'      => false,
			'rewrite'           => [
				'slug'       => NoisaToolkit::getInstance()->get_theme_option( 'releases_slug', 'releases' ),
				'with_front' => false,
			],
			'supports'          => $this->supports,
			'menu_icon'         => $this->icon,
		];


		// Register taxonomy
		register_taxonomy( 'noisa_releases_artists', [ $this->post_name ], [
			'hierarchical'   => true,
			'label'          => esc_html__( 'Artists', 'noisa-toolkit' ),
			'singular_label' => esc_html__( 'Artist', 'noisa-toolkit' ),
			'query_var'      => true,
			'rewrite'        => [
				'slug'       => NoisaToolkit::getInstance()->get_theme_option( 'releases_artists_slug', 'release-artist' ),
				'with_front' => false,
			],
		]);

		// Register taxonomy
		register_taxonomy( 'noisa_releases_genres', [ $this->post_name ], [
			'hierarchical'   => true,
			'label'          => esc_html__( 'Genres', 'noisa-toolkit' ),
			'singular_label' => esc_html__( 'Genre', 'noisa-toolkit' ),
			'query_var'      => true,
			'rewrite'        => [
				'slug'       => NoisaToolkit::getInstance()->get_theme_option( 'releases_genres_slug', 'release-genre' ),
				'with_front' => false,
			],
		]);

		// Register taxonomy
		register_taxonomy( 'noisa_releases_cats', [ $this->post_name ], [
			'hierarchical'   => true,
			'label'          => esc_html__( 'Categories', 'noisa-toolkit' ),
			'singular_label' => esc_html__( 'Category', 'noisa-toolkit' ),
			'query_var'      => true,
			'rewrite'        => [
				'slug'       => NoisaToolkit::getInstance()->get_theme_option( 'releases_cat_slug', 'release-category' ),
				'with_front' => false,
			],
		]);


		// Add Class instance
		$this->cpt = new RascalsCPT( $args, $post_options );

		// Add columns filter
		$columns_filter_args = [
			'post_name'    => $this->post_name,
			'filter_label' => esc_html__( 'Filter', 'noisa-toolkit' ),
			'filters'      => [
				'noisa_releases_artists',
				'noisa_releases_genres',
				'noisa_releases_cats',
			],
			'extra_cols'   => [
				'cb'      => '<input type="checkbox" />',
				'title'   => esc_html__( 'Title', 'noisa-toolkit' ),
				'date'    => esc_html__( 'Date', 'noisa-toolkit' ),
				'preview' => esc_html__( 'Preview', 'noisa-toolkit' ),
			],
		];

		$this->cpt->addAdminColumns( $columns_filter_args );
	}
}
