<?php
/**
 * Rascals Register Slider
 *
 * @author Rascals Themes
 * @category Core
 * @package Noisa Toolkit
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


class RascalsRegisterSlider extends RascalsCPT {

	/**
	 * Instance of RascalsCPT 
	 *
	 * @var class
	 */
	private $cpt; 

	/*
	Public variables
	 */
	public $post_name = 'noisa_slider';
	public $icon      = 'dashicons-slides';
	public $supports  = [ 'title', 'editor' ];

	/**
	 * Rascals CPT Constructor.
	 *
	 * @return void
	 */
	public function __construct() {
		$this->init();
	}

	/**
	 * Initialize class
	 *
	 * @return void
	 */
	public function init() {
		add_action( 'init', [ $this, 'regsiterPostType' ], 0 );
	}

	/**
	 * Register Post Type
	 *
	 * @return void
	 */
	public function regsiterPostType() {

		/* Class arguments */
		$args = [ 
			'post_name' => $this->post_name, 
			'sortable'  => false,
		];

		// Post arguments
		$post_options = [
			'labels'            => [
				'name'               => esc_html__( 'Slider', 'noisa-toolkit' ),
				'singular_name'      => esc_html__( 'Slider', 'noisa-toolkit' ),
				'add_new'            => esc_html__( 'Add New', 'noisa-toolkit' ),
				'add_new_item'       => esc_html__( 'Add New Slider Item', 'noisa-toolkit' ),
				'edit_item'          => esc_html__( 'Edit Slider Item', 'noisa-toolkit' ),
				'new_item'           => esc_html__( 'New Slider Item', 'noisa-toolkit' ),
				'view_item'          => esc_html__( 'View Slider Item', 'noisa-toolkit' ),
				'search_items'       => esc_html__( 'Search Items', 'noisa-toolkit' ),
				'not_found'          => esc_html__( 'No slider found', 'noisa-toolkit' ),
				'not_found_in_trash' => esc_html__( 'No slider found in Trash', 'noisa-toolkit' ), 
				'parent_item_colon'  => '',
			],
			'public'            => true,
			'show_ui'           => true,
			'show_in_nav_menus' => true,
			'capability_type'   => 'post',
			'hierarchical'      => false,
			'rewrite'           => [
				'slug'       => NoisaToolkit::getInstance()->get_theme_option( 'slider_slug', 'sliders' ),
				'with_front' => false,
			],
			'supports'          => $this->supports,
			'menu_icon'         => $this->icon,
		];
		
		// Add Class instance
		$this->cpt = new RascalsCPT( $args, $post_options );

		// Add columns filter
		$columns_filter_args = [
			'post_name'  => $this->post_name,
			'extra_cols' => [
				'cb'      => '<input type="checkbox" />',
				'title'   => esc_html__( 'Title', 'noisa-toolkit' ),
				'date'    => esc_html__( 'Date', 'noisa-toolkit' ),
				'preview' => esc_html__( 'Preview', 'noisa-toolkit' ),
				'id'      => esc_html__( 'ID', 'noisa-toolkit' ),
			],
		];

		$this->cpt->addAdminColumns( $columns_filter_args );
	}


	/**
	 * Get slider parameters in arrary
	 *
	 * @param  integer $slider_id
	 * @return array
	 */
	public function getSlider( $slider_id ) {
		
		$images_ids = get_post_meta( $slider_id, '_custom_slider', true );

		if ( ! $images_ids || $images_ids == '' ) {
			return false;
		}

		$count    = 0;
		$ids      = explode( '|', $images_ids );
		$defaults = [
			'image_type'    => 'image', // image, lightbox, media, link, link_blank,
			'video'         => '',
			'src'           => '',
			'lightbox_link' => '',
			'link'          => '',
			'media_code'    => '',
			'media_link'    => '',
			'music'         => false,
			'track_id'      => 0, // track id
			'title'         => '',
			'subtitle'      => '',
		];

		$slider = [];

		// Start Loop 
		foreach ( $ids as $id ) {

			// Vars 
			$title    = '';
			$subtitle = '';

			// Get image data
			$image_att = wp_get_attachment_image_src( $id );

			if ( ! $image_att[0] ) {
				continue;
			}

			++$count;

			// Meta
			$slide = get_post_meta( $slider_id, '_custom_slider_' . $id, true );

			// Add default values 
			if ( isset( $slide ) && is_array( $slide ) ) {
				$slide = array_merge( $defaults, $slide );
			} else {
				$slide = $defaults;
			}

			if ( $slide['music'] == 'yes' ) {
				$slide['music'] = true;
			} else {
				$slide['music'] = false;
			}

			$slide['track_id'] = (int) $slide['track_id'];

			// Add image src to array 
			$slide['src'] = wp_get_attachment_url( $id );

			array_push( $slider, $slide );
		}
		return $slider;
	}
}
