<?php
/**
 * Theme Name:      Noisa
 * Theme Author:    Mariusz Rek - Rascals Themes
 * Theme URI:       http://rascalsthemes.com/noisa
 * Author URI:      http://rascalsthemes.com
 * File:            panel-options.php
 *
 * @package noisa
 * @since 1.0.0
 */

/* Exit if accessed directly */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/* Options array */
$noisa_main_options = [ 

	/*
	==================================================
		General Settings 
	================================================== */
	[ 
		'type'     => 'open',
		'tab_name' => esc_html__( 'General Settings', 'noisa' ),
		'tab_id'   => 'general-settings',
		'icon'     => 'gears',
	],

	[ 
		'type'         => 'sub_open',
		'sub_tab_name' => esc_html__( 'General Settings', 'noisa' ),
		'sub_tab_id'   => 'sub-general-basics',
	],

	// Google MAPS API Key
	[
		'name' => esc_html__( 'Google Maps API Key', 'noisa' ),
		'id'   => 'google_maps_key',
		'type' => 'text',
		'std'  => '',
		'desc' => esc_html__( 'Insert your Google Maps API key.', 'noisa' ),
	],

	// Google Map Marker
	[
		'name'         => esc_html__( 'Google Maps Marker', 'noisa' ),
		'id'           => 'map_marker',
		'type'         => 'add_image',
		'source'       => 'media_libary',
		'plugins'      => [ 'add_image' ],
		'std'          => '',
		'button_title' => esc_html__( 'Add Image', 'noisa' ),
		'msg'          => esc_html__( 'Currently you don\'t have image, you can add one by clicking on the button below.', 'noisa' ),
		'desc'         => esc_html__( 'Add Google Map Marker (48px x 56px).', 'noisa' ),
	],

			
	[ 
		'type' => 'sub_close',
	],

	[ 
		'type' => 'close',
	],


	/*
	==================================================
		Fonts 
	================================================== */
	[ 
		'type'     => 'open',
		'tab_name' => esc_html__( 'Fonts', 'noisa' ),
		'tab_id'   => 'fonts',
		'icon'     => 'font',
	],

	/*
	Google Fonts
		-------------------------------- */
		[
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Google Web Fonts', 'noisa' ),
			'sub_tab_id'   => 'sub-google-fonts',
		],
	[
		'name'    => esc_html__( 'Google Fonts', 'noisa' ),
		'id'      => 'use_google_fonts',
		'type'    => 'switch_button',
		'plugins' => [ 'switch_button' ],
		'std'     => 'on',
		'desc'    => esc_html__( 'When this option is enabled, the text elements will be automatically replaced with the Google Web Fonts.', 'noisa' ),
	],
	[
		'name'       => esc_html__( 'Google Font Code', 'noisa' ),
		'id'         => 'google_fonts_code',
		'type'       => 'textarea',
		'std'        => esc_html__( 'Source+Sans+Pro:300,300i,400,400i,600,600i,700,700i&amp;subset=latin-ext', 'noisa' ),
		'tinymce'    => 'false',
		'height'     => '50',
		'desc'       => esc_html__( 'Add Google Fonts family.', 'noisa' ),
		'dependency' => [
			'element' => 'use_google_fonts',
			'value'   => [ 'on' ],
		],
	],
	[
		'type' => 'sub_close',
	],
		

	[ 
		'type' => 'close',
	],


	/*
	==================================================
		Sections 
	================================================== */
	[ 
		'type'     => 'open',
		'tab_name' => esc_html__( 'Sections', 'noisa' ),
		'tab_id'   => 'plugins',
		'icon'     => 'th-large',
	],  

	/*
	Comments
		-------------------------------- */
		[
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Comments', 'noisa' ),
			'sub_tab_id'   => 'sub-sections-comments',
		],

	// Custom Comments Date
	[
		'name' => esc_html__( 'Comment Date Format', 'noisa' ),
		'id'   => 'custom_comment_date',
		'type' => 'text',
		'std'  => 'F j, Y (H:i)',
		'desc' => esc_html__( 'Enter your custom comment date.', 'noisa' ),
	],

	[
		'name'    => esc_html__( 'DISQUS Comments', 'noisa' ),
		'id'      => 'disqus_comments',
		'type'    => 'switch_button',
		'plugins' => [ 'switch_button' ],
		'std'     => 'off',
		'desc'    => esc_html__( 'Enable DISQUS comments. Replace default Wordpress comments.', 'noisa' ),
	],

	// Disqus ID
	[
		'name'       => esc_html__( 'DISQUS Shortname', 'noisa' ),
		'id'         => 'disqus_shortname',
		'type'       => 'text',
		'std'        => '',
		'desc'       => esc_html__( 'Enter DISQUS Website\'s Shortname.', 'noisa' ),
		'dependency' => [
			'element' => 'disqus_comments',
			'value'   => [ 'on' ],
		],
	],

	[
		'type' => 'sub_close',
	],


	/*
	Music Player
		-------------------------------- */
		[
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Music', 'noisa' ),
			'sub_tab_id'   => 'sub-sections-music',
		],

	// Enable Scamp Player
	[
		'name'    => esc_html__( 'Music Player', 'noisa' ),
		'id'      => 'scamp_player',
		'type'    => 'switch_button',
		'plugins' => [ 'switch_button' ],
		'std'     => 'on',
		'desc'    => esc_html__( 'Enable music player. NOTE: Noisa Plugin must be instaled and activated.', 'noisa' ),
	],

	// Autoplay
			[
				'name'       => esc_html__( 'Autoplay', 'noisa' ),
				'id'         => 'player_autoplay',
				'type'       => 'switch_button',
				'plugins'    => [ 'switch_button' ],
				'std'        => 'off',
				'desc'       => esc_html__( 'Autoplay tracklist. NOTE: Autoplay does not work on mobile devices.', 'noisa' ),
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],

	// Load first track
			[
				'name'       => esc_html__( 'Load First Track', 'noisa' ),
				'id'         => 'load_first_track',
				'type'       => 'switch_button',
				'plugins'    => [ 'switch_button' ],
				'std'        => 'off',
				'desc'       => esc_html__( 'Load first track from tracklist after load list.', 'noisa' ),
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],

	// Startup Tracklist
			[ 
				'name'       => esc_html__( 'Startup Tracklist', 'noisa' ),
				'id'         => 'startup_tracklist',
				'type'       => 'posts',
				'post_type'  => 'noisa_tracks',
				'std'        => 'none',
				'options'    => [
					[ 'name' => '', 'value' => 'none' ],
				],
				'desc'       => esc_html__( 'Select startup tracklist.', 'noisa' ),
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],

	// Show Player
			[
				'name'       => esc_html__( 'Show Player on Startup', 'noisa' ),
				'id'         => 'show_player',
				'type'       => 'switch_button',
				'plugins'    => [ 'switch_button' ],
				'std'        => 'off',
				'desc'       => esc_html__( 'Show player on startup. NOTE: Player will not be visible when option "Open Player After Click" is enabled.', 'noisa' ),
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],

	// Show Tracklist
			[
				'name'       => esc_html__( 'Show Tracklist on Startup', 'noisa' ),
				'id'         => 'show_tracklist',
				'type'       => 'switch_button',
				'plugins'    => [ 'switch_button' ],
				'std'        => 'off',
				'desc'       => esc_html__( 'Show playlist on startup.', 'noisa' ),
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],

	// Base64
			[
				'name'       => esc_html__( 'Encode Tracks URLS (Base64)', 'noisa' ),
				'id'         => 'player_base64',
				'type'       => 'switch_button',
				'plugins'    => [ 'switch_button' ],
				'std'        => 'off',
				'desc'       => esc_html__( 'Set this to on when you would like to use the base64 PHP function, to hide the MP3 URL.', 'noisa' ),
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],

	// Random Tracks
			[
				'name'       => esc_html__( 'Random Play', 'noisa' ),
				'id'         => 'player_random',
				'type'       => 'switch_button',
				'plugins'    => [ 'switch_button' ],
				'std'        => 'off',
				'desc'       => esc_html__( 'Random play tracks.', 'noisa' ),
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],

	// Loop Tracks
			[
				'name'       => esc_html__( 'Loop Tracklist', 'noisa' ),
				'id'         => 'player_loop',
				'type'       => 'switch_button',
				'plugins'    => [ 'switch_button' ],
				'std'        => 'off',
				'desc'       => esc_html__( 'Loop tracklist.', 'noisa' ),
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],

	// Titlebar
			[
				'name'       => esc_html__( 'Change Titlebar', 'noisa' ),
				'id'         => 'player_titlebar',
				'type'       => 'switch_button',
				'plugins'    => [ 'switch_button' ],
				'std'        => 'off',
				'desc'       => esc_html__( 'Replace browser titlebar on track title.', 'noisa' ),
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],

	// Player Skin
			[ 
				'name'       => esc_html__( 'Player Skin', 'noisa' ),
				'id'         => 'player_skin',
				'type'       => 'select',
				'std'        => 'dark',
				'desc'       => esc_html__( 'Select player skin.', 'noisa' ),
				'options'    => [ 
					[ 'name' => 'Light Compact', 'value' => 'light.compact' ],
					[ 'name' => 'Dark Compact', 'value' => 'dark.compact' ],
					[ 'name' => 'Light', 'value' => 'light' ],
					[ 'name' => 'Dark', 'value' => 'dark' ],
				],
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],

	// Soundcloud 
			[
				'name'       => esc_html__( 'Soundcloud', 'noisa' ),
				'id'         => 'soundcloud',
				'type'       => 'switch_button',
				'plugins'    => [ 'switch_button' ],
				'std'        => 'on',
				'desc'       => esc_html__( 'Soundcloud Playback', 'noisa' ),
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],

	// Soundcloud Client ID
			[
				'name'       => esc_html__( 'Soundcloud Client ID', 'noisa' ),
				'id'         => 'soundcloud_id',
				'type'       => 'text',
				'std'        => '',
				'desc'       => esc_html__( 'Add your Soundcloud ID', 'noisa' ),
				'dependency' => [
					'element' => 'soundcloud',
					'value'   => [ 'on' ],
				],
			],

	// Shoutcast Radio
			[
				'name'       => esc_html__( 'Shoutcast Radio', 'noisa' ),
				'id'         => 'shoutcast',
				'type'       => 'switch_button',
				'std'        => 'on',
				'desc'       => esc_html__( 'Shoutcast support.', 'noisa' ),
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],

	// Shoutcast Refresh Time
			[
				'name'       => esc_html__( 'Shoutcast Refresh Time (ms)', 'noisa' ),
				'id'         => 'shoutcast_interval',
				'type'       => 'text',
				'std'        => '20000',
				'desc'       => esc_html__( 'Enter refresh time in ms. (20000 = 20s)', 'noisa' ),
				'dependency' => [
					'element' => 'shoutcast',
					'value'   => [ 'on' ],
				],
			],

	// Startup Volume
			[ 
				'name'       => esc_html__( 'Startup Volume', 'noisa' ),
				'id'         => 'player_volume',
				'type'       => 'range',
				'plugins'    => [ 'range' ],
				'min'        => 0,
				'max'        => 100,
				'unit'       => '',
				'std'        => '70',
				'desc'       => esc_html__( 'Set startup volume.', 'noisa' ),
				'dependency' => [
					'element' => 'scamp_player',
					'value'   => [ 'on' ],
				],
			],
			
	[
		'type' => 'sub_close',
	],


	/*
	==================================================
			Blog 
		================================================== */
		[
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Blog', 'noisa' ),
			'sub_tab_id'   => 'sub-section-blog',
		],

	// Featured image
	[
		'name'    => esc_html__( 'Display Featured Image on Standard Post Format', 'noisa' ),
		'id'      => 'display_featured_image',
		'type'    => 'switch_button',
		'plugins' => [ 'switch_button' ],
		'std'     => 'on',
		'desc'    => '',
	],

	// Featured image 2
	[
		'name'    => esc_html__( 'Display Featured Image on Single Post (Image Format)', 'noisa' ),
		'id'      => 'display_featured_image_ipf',
		'type'    => 'switch_button',
		'plugins' => [ 'switch_button' ],
		'std'     => 'on',
		'desc'    => '',
	],

	// Category type
			[
				'name'    => esc_html__( 'Category/Tag/Search Type', 'noisa' ),
				'id'      => 'blog_cat_type',
				'type'    => 'select', 'std' => 'boxed',
				'options' => [
					[ 'name' => esc_html__( 'List (Default)', 'noisa' ), 'value' => 'list' ],
					[ 'name' => esc_html__( 'Grid', 'noisa' ), 'value' => 'grid' ],
				],
				'desc'    => '',   
			],

	// Category layout
			[
				'name'       => esc_html__( 'Grid Layout', 'noisa' ),
				'id'         => 'blog_cat_layout',
				'type'       => 'select', 'std' => 'boxed',
				'options'    => [
					[ 'name' => esc_html__( 'Boxed', 'noisa' ), 'value' => 'boxed' ],
					[ 'name' => esc_html__( 'Full width', 'noisa' ), 'value' => 'full-width' ],
				],
				'desc'       => '',
				'dependency' => [
					'element' => 'blog_cat_type',
					'value'   => [ 'grid' ],
				],   
			],

	[
		'type' => 'sub_close',
	],


	/*
	==================================================
			Events 
		================================================== */
		[
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Events', 'noisa' ),
			'sub_tab_id'   => 'sub-section-events',
		],  

	// Custom Event Date
	[
		'name' => esc_html__( 'Event Date Format', 'noisa' ),
		'id'   => 'event_date',
		'type' => 'text',
		'std'  => 'd/m',
		'desc' => esc_html__( 'Enter your custom event date. More information: http://codex.wordpress.org/Formatting_Date_and_Time', 'noisa' ),
	],

	// Custom Time
	[
		'name' => esc_html__( 'Event Time Format', 'noisa' ),
		'id'   => 'event_time',
		'type' => 'text',
		'std'  => 'g:i A',
		'desc' => esc_html__( 'Enter your custom event time e.g: H:i. If time field isn\'t empty the then the time is displayed after event date. More information: http://codex.wordpress.org/Formatting_Date_and_Time', 'noisa' ),
	],
	[
		'name'    => esc_html__( 'Category Thumbnails Gap', 'noisa' ),
		'id'      => 'gap_events',
		'type'    => 'select',
		'std'     => 'no-gap',
		'options' => [
			[ 'name' => esc_html__( 'Small Gap', 'noisa' ), 'value' => 'no-gap' ],
			[ 'name' => esc_html__( 'Medium gap', 'noisa' ), 'value' => 'medium-gap' ],
		],
		'desc'    => esc_html__( 'Display gap between thumbnails.', 'noisa' ),
	],
			
	[
		'type' => 'sub_close',
	],


	/*
	==================================================
			Artists 
		================================================== */
		[
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Artists', 'noisa' ),
			'sub_tab_id'   => 'sub-section-artists',
		],

	// Category Layout
			[
				'name'    => esc_html__( 'Category Layout', 'noisa' ),
				'id'      => 'artists_cat_layout',
				'type'    => 'select', 'std' => 'boxed',
				'options' => [
					[ 'name' => esc_html__( 'Boxed', 'noisa' ), 'value' => 'boxed' ],
					[ 'name' => esc_html__( 'Full width', 'noisa' ), 'value' => 'full-width' ],
				],
				'desc'    => '',   
			],
	[
		'name'    => esc_html__( 'Category Thumbnails Gap', 'noisa' ),
		'id'      => 'gap_artists',
		'type'    => 'select',
		'std'     => 'no-gap',
		'options' => [
			[ 'name' => esc_html__( 'Small Gap', 'noisa' ), 'value' => 'no-gap' ],
			[ 'name' => esc_html__( 'Medium gap', 'noisa' ), 'value' => 'medium-gap' ],
		],
		'desc'    => esc_html__( 'Display gap between thumbnails.', 'noisa' ),
	],
	[
		'type' => 'sub_close',
	],


	/*
	==================================================
			Releases 
		================================================== */
		[
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Releases', 'noisa' ),
			'sub_tab_id'   => 'sub-section-releases',
		],

	// Category Layout
			[
				'name'    => esc_html__( 'Category Layout', 'noisa' ),
				'id'      => 'releases_cat_layout',
				'type'    => 'select', 'std' => 'boxed',
				'options' => [
					[ 'name' => esc_html__( 'Boxed', 'noisa' ), 'value' => 'boxed' ],
					[ 'name' => esc_html__( 'Full width', 'noisa' ), 'value' => 'full-width' ],
				],
				'desc'    => '',   
			],
	[
		'name'    => esc_html__( 'Category Thumbnails Gap', 'noisa' ),
		'id'      => 'gap_releases',
		'type'    => 'select',
		'std'     => 'no-gap',
		'options' => [
			[ 'name' => esc_html__( 'Small Gap', 'noisa' ), 'value' => 'no-gap' ],
			[ 'name' => esc_html__( 'Medium gap', 'noisa' ), 'value' => 'medium-gap' ],
		],
		'desc'    => esc_html__( 'Display gap between thumbnails.', 'noisa' ),
	],
	[
		'type' => 'sub_close',
	],


	/*
	==================================================
			Gallery
		================================================== */
		[
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Gallery', 'noisa' ),
			'sub_tab_id'   => 'sub-section-gallery',
		],

	// Category Layout
			[
				'name'    => esc_html__( 'Category Layout', 'noisa' ),
				'id'      => 'gallery_cat_layout',
				'type'    => 'select', 'std' => 'boxed',
				'options' => [
					[ 'name' => esc_html__( 'Boxed', 'noisa' ), 'value' => 'boxed' ],
					[ 'name' => esc_html__( 'Full width', 'noisa' ), 'value' => 'full-width' ],
				],
				'desc'    => '',   
			],
	[
		'name'    => esc_html__( 'Category Thumbnails Gap', 'noisa' ),
		'id'      => 'gap_gallery',
		'type'    => 'select',
		'std'     => 'no-gap',
		'options' => [
			[ 'name' => esc_html__( 'Small Gap', 'noisa' ), 'value' => 'no-gap' ],
			[ 'name' => esc_html__( 'Medium gap', 'noisa' ), 'value' => 'medium-gap' ],
		],
		'desc'    => esc_html__( 'Display gap between thumbnails.', 'noisa' ),
	],
	[
		'type' => 'sub_close',
	],


	/*
	==================================================
			Permalinks 
		================================================== */
		[
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Permalinks', 'noisa' ),
			'sub_tab_id'   => 'sub-section-permalinks',
		],  
			
			
	// Artists
	[
		'name' => esc_html__( 'Artists Slug', 'noisa' ),
		'id'   => 'artists_slug',
		'type' => 'text',
		'std'  => 'artists',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],
	[
		'name' => esc_html__( 'Artists Categories Slug', 'noisa' ),
		'id'   => 'artists_cat_slug',
		'type' => 'text',
		'std'  => 'artist-category',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],
	[
		'name' => esc_html__( 'Artists Genres Slug', 'noisa' ),
		'id'   => 'artists_genres_slug',
		'type' => 'text',
		'std'  => 'artist-genre',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],

	// Releases
	[
		'name' => esc_html__( 'Releases Slug', 'noisa' ),
		'id'   => 'releases_slug',
		'type' => 'text',
		'std'  => 'releases',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],
	[
		'name' => esc_html__( 'Releases Genres Slug', 'noisa' ),
		'id'   => 'releases_genres_slug',
		'type' => 'text',
		'std'  => 'release-genre',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],
	[
		'name' => esc_html__( 'Releases Categories Slug', 'noisa' ),
		'id'   => 'releases_cat_slug',
		'type' => 'text',
		'std'  => 'release-category',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],
	[
		'name' => esc_html__( 'Releases Artists Slug', 'noisa' ),
		'id'   => 'releases_artists_slug',
		'type' => 'text',
		'std'  => 'release-artist',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],

	// Events
	[
		'name' => esc_html__( 'Events Slug', 'noisa' ),
		'id'   => 'events_slug',
		'type' => 'text',
		'std'  => 'events',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],
	[
		'name' => esc_html__( 'Events Artists Slug', 'noisa' ),
		'id'   => 'events_artists_slug',
		'type' => 'text',
		'std'  => 'event-artist',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],
	[
		'name' => esc_html__( 'Events Categories Slug', 'noisa' ),
		'id'   => 'events_cat_slug',
		'type' => 'text',
		'std'  => 'event-category',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],
	[
		'name' => esc_html__( 'Events Location Slug', 'noisa' ),
		'id'   => 'events_locations_slug',
		'type' => 'text',
		'std'  => 'event-location',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],

	// Gallery
	[
		'name' => esc_html__( 'Gallery Slug', 'noisa' ),
		'id'   => 'gallery_slug',
		'type' => 'text',
		'std'  => 'galleries',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],
	[
		'name' => esc_html__( 'Gallery Artists Slug', 'noisa' ),
		'id'   => 'gallery_artists_slug',
		'type' => 'text',
		'std'  => 'gallery-artist',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],
	[
		'name' => esc_html__( 'Gallery Categories Slug', 'noisa' ),
		'id'   => 'gallery_cat_slug',
		'type' => 'text',
		'std'  => 'gallery-category',
		'desc' => esc_html__( 'Enter post slug name. No special characters. No spaces. IMPORTANT: When you change post slug name, you have to go to: WordPress Settings > Permalinks and save settings.', 'noisa' ),
	],
			
			
	[
		'type' => 'sub_close',
	],
		

	[ 
		'type' => 'close',
	],


	/*
	==================================================
		Sidebars 
	================================================== */
	[
		'type'     => 'open',
		'tab_name' => esc_html__( 'Sidebars', 'noisa' ),
		'tab_id'   => 'sidebars',
		'icon'     => 'bars',
	],
	[
		'type'         => 'sub_open',
		'sub_tab_name' => esc_html__( 'Sidebars', 'noisa' ),
		'sub_tab_id'   => 'sub-sidebars',
	],
	[
		'name'        => esc_html__( 'Sidebars', 'noisa' ),
		'sortable'    => false,
		'array_name'  => 'custom_sidebars',
		'id'          => [
			[ 'name' => 'name', 'id' => 'sidebar', 'label' => 'Name:', 'type' => 'text' ],
		],
		'type'        => 'sortable_list',
		'button_text' => esc_html__( 'Add Sidebar', 'noisa' ),
		'desc'        => esc_html__( 'Add your custom sidebars.', 'noisa' ),
	],
	[
		'type' => 'sub_close',
	],
	[
		'type' => 'close',
	],


	/*
	==================================================
		Advanced 
	================================================== */
	[ 
		'type'     => 'open',
		'tab_name' => esc_html__( 'Advanced', 'noisa' ),
		'tab_id'   => 'advanced',
		'icon'     => 'wrench',
	],

	/*
	AJAX
		-------------------------------- */
		[
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Ajax', 'noisa' ),
			'sub_tab_id'   => 'sub-ajax',
		],

	// Ajax
	[ 
		'name'    => esc_html__( 'Ajax Load', 'noisa' ),
		'id'      => 'ajaxed',
		'type'    => 'switch_button',
		'plugins' => [ 'switch_button' ],
		'std'     => 'on',
		'desc'    => esc_html__( 'Enable if you want ajax loading.', 'noisa' ),
	],

	// Ajax Async
			[
				'name'       => esc_html__( 'Asynchronous', 'noisa' ),
				'id'         => 'ajax_async',
				'type'       => 'switch_button',
				'plugins'    => [ 'switch_button' ],
				'std'        => 'on',
				'desc'       => esc_html__( 'Asynchronous AJAX.', 'noisa' ),
				'dependency' => [
					'element' => 'ajaxed',
					'value'   => [ 'on' ],
				],
			],

	// Ajax Cache
			[
				'name'       => esc_html__( 'Ajax Cache', 'noisa' ),
				'id'         => 'ajax_cache',
				'type'       => 'switch_button',
				'plugins'    => [ 'switch_button' ],
				'std'        => 'off',
				'desc'       => esc_html__( 'AJAX Cache.', 'noisa' ),
				'dependency' => [
					'element' => 'ajaxed',
					'value'   => [ 'on' ],
				],
			],

	// Ajax Elements
			[ 
				'name'       => esc_html__( 'AJAX Filter', 'noisa' ),
				'id'         => 'ajax_elements',
				'type'       => 'textarea',
				'tinymce'    => 'false',
				'std'        => '',
				'height'     => '120',
				'desc'       => esc_html__( 'Add selectors (Note: divide links with linebreaks (Enter)). These elements will not be processed by AJAX.', 'noisa' ),
				'dependency' => [
					'element' => 'ajaxed',
					'value'   => [ 'on' ],
				],
			],

	// Ajax autoload scripts
			[
				'name'        => esc_html__( 'AJAX Autoload Scripts', 'noisa' ),
				'sortable'    => true,
				'array_name'  => 'ajax_autoload_scripts',
				'id'          => [
					[ 'name' => 'id', 'id' => 'id', 'label' => 'ID:' ],
					[ 'name' => 'url', 'id' => 'url', 'label' => 'URL:' ],
				],
				'type'        => 'sortable_list',
				'button_text' => esc_html__( 'Add Script', 'noisa' ),
				'desc'        => esc_html__( 'Add urls and ids of scripts that will be autoloaded.', 'noisa' ),
				'dependency'  => [
					'element' => 'ajaxed',
					'value'   => [ 'on' ],
				],
			],

	// Ajax reload scripts
			[ 
				'name'       => esc_html__( 'AJAX Reload Scripts', 'noisa' ),
				'id'         => 'ajax_reload_scripts',
				'type'       => 'textarea',
				'tinymce'    => 'false',
				'std'        => '',
				'height'     => '120',
				'desc'       => esc_html__( 'Add strings for reloaded scripts (Note: divide links with linebreaks (Enter)). These scripts will be reloaded after page loaded by AJAX.', 'noisa' ),
				'dependency' => [
					'element' => 'ajaxed',
					'value'   => [ 'on' ],
				],
			],

	// Ajax reload containers
			[ 
				'name'       => esc_html__( 'AJAX Reload Containers', 'noisa' ),
				'id'         => 'ajax_reload_containers',
				'type'       => 'textarea',
				'tinymce'    => 'false',
				'std'        => '',
				'height'     => '120',
				'desc'       => esc_html__( 'Add strings for reloaded containers (Note: divide links with linebreaks (Enter)). These containers will be reloaded after page loaded by AJAX.', 'noisa' ),
				'dependency' => [
					'element' => 'ajaxed',
					'value'   => [ 'on' ],
				],
			],

	// Ajax exclude links
			[ 
				'name'       => esc_html__( 'AJAX Exclude Links', 'noisa' ),
				'id'         => 'ajax_exclude_links',
				'type'       => 'textarea',
				'tinymce'    => 'false',
				'std'        => '',
				'height'     => '120',
				'desc'       => esc_html__( 'Add links that should be excluded from AJAX loader (Note: divide links with linebreaks (Enter)). These pages will not be loaded by AJAX.', 'noisa' ),
				'dependency' => [
					'element' => 'ajaxed',
					'value'   => [ 'on' ],
				],
			],

	// Ajax events
			[ 
				'name'       => esc_html__( 'AJAX Events', 'noisa' ),
				'id'         => 'ajax_events',
				'type'       => 'textarea',
				'tinymce'    => 'false',
				'std'        => '',
				'height'     => '120',
				'desc'       => esc_html__( 'Add Javascript events (Note: divide links with linebreaks (Enter)). These events will be removed after page page by AJAX.', 'noisa' ),
				'dependency' => [
					'element' => 'ajaxed',
					'value'   => [ 'on' ],
				],
			],
	[
		'type' => 'sub_close',
	],


	/*
	Plugins
		-------------------------------- */
		[
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Plugins', 'noisa' ),
			'sub_tab_id'   => 'sub-plugins',
		],

	// Retina Displays
	[ 
		'name'    => esc_html__( 'Retina Displays', 'noisa' ),
		'id'      => 'retina',
		'type'    => 'switch_button',
		'plugins' => [ 'switch_button' ],
		'std'     => 'off',
		'desc'    => esc_html__( 'To make this work you need to specify the width and the height of the image directly and provide the same image twice the size withe the @2x selector added at the end of the image name. For instance if you want your "logo.png" file to be retina compatible just include it in the markup with specified width and height ( the width and height of the original image in pixels ) and create a "logo@2x.png" file in the same directory that is twice the resolution.', 'noisa' ),
	],

	// VC Frontend
	[ 
		'name'    => esc_html__( 'Visual Composer Frontend Editor', 'noisa' ),
		'id'      => 'vc_frontend',
		'type'    => 'switch_button',
		'plugins' => [ 'switch_button' ],
		'std'     => 'off',
		'desc'    => esc_html__( 'Enable Visual Composer frontend editor. Please Note: The editor may not work properly when AJAX is enabled.', 'noisa' ),
	],

			
	[
		'type' => 'sub_close',
	],
		

	/*
	Import/Export
		-------------------------------- */
		[ 
			'type'         => 'sub_open',
			'sub_tab_name' => esc_html__( 'Import/Export', 'noisa' ),
			'sub_tab_id'   => 'sub-import',
		],
	[ 
		'type' => 'export',
	],
	[ 
		'type' => 'import',
	],
	[ 
		'type' => 'sub_close',
	],

	[ 
		'type' => 'close',
	],


	/*
	==================================================
		Outdated 
	================================================== */
	[ 
		'type'     => 'open',
		'tab_name' => esc_html__( 'Outdated', 'noisa' ),
		'tab_id'   => 'outdated',
		'icon'     => 'warning',
	],
	[
		'type'         => 'sub_open',
		'sub_tab_name' => esc_html__( 'Outdated Options', 'noisa' ),
		'sub_tab_id'   => 'sub-outdated',
	],
	[
		'name'   => esc_html__( 'CSS Code', 'noisa' ),
		'type'   => 'textarea',
		'std'    => '',
		'height' => '200',
		'desc'   => esc_html__( 'Please copy and paste your CSS code to visual customizer. Go to Appearance > Customize > Additional CSS ', 'noisa' ) . '<a href="' . admin_url( '/customize.php' ) . '">Customizer</a>',
		'id'     => 'custom_css',
	],
	[
		'name'   => esc_html__( 'Javascript Code', 'noisa' ),
		'type'   => 'textarea',
		'std'    => '',
		'height' => '200',
		'desc'   => esc_html__( 'Please copy and paste your JS code to visual customizer. Go to Appearance > Customize > Additional Javascript ', 'noisa' ) . '<a href="' . admin_url( '/customize.php' ) . '">Customizer</a>',
		'id'     => 'custom_js',
	],

	[
		'name'   => esc_html__( 'Integrate The Fonts Into Your CSS', 'noisa' ),
		'id'     => 'google_code',
		'type'   => 'textarea',
		'height' => '100',
		'std'    => '',
		'desc'   => esc_html__( 'Please copy and paste your CSS code to visual customizer. Go to Appearance > Customize > Additional CSS ', 'noisa' ) . '<a href="' . admin_url( '/customize.php' ) . '">Customizer</a>',
	],

	[ 
		'type' => 'sub_close',
	],

	[ 
		'type' => 'close',
	],


	/*
	==================================================
		Hidden fields
	================================================== */
	[ 
		'type'  => 'hidden_field',
		'id'    => 'theme_name',
		'value' => 'noisa',
	],
	
];


/*
==================================================
	Init Panel 
================================================== */

/* Class arguments */
$args = [
	'menu_name'   => esc_html__( 'Theme Panel', 'noisa' ), 
	'option_name' => 'noisa_panel_opts',
	'menu_icon'   => '',
];

/* Add class instance */
$main_panel = new RascalsThemePanel( $args, $noisa_main_options );


/*
==================================================
	Get Theme Options 
================================================== */
function noisa_opts() {
	global $main_panel;
	return $main_panel;
}
