<?php
/**
 * Template Name: Artists
 *
 * @package noisa
 * @since 1.0.0
 */

get_header(); 

// Get Custom Intro Section
get_template_part( 'inc/custom-intro' );

// Get panel options
$noisa_opts = noisa_opts();

// Copy query
$temp_post  = $post;
$query_temp = $wp_query;

// Pagination Limit
$limit = (int) get_post_meta( $wp_query->post->ID, '_limit', true );
$limit = $limit && $limit === '' ? $limit = 6 : $limit = $limit;

// Gap
$gap = get_post_meta( $wp_query->post->ID, '_gap', true );

// Artists layout
$artists_layout = get_post_meta( $wp_query->post->ID, '_artists_layout', true );

// Date format
$date_format = get_option( 'date_format' );

if ( $artists_layout === 'full-width' ) {
	$artists_cols = '3';
}

// Filters
$filters = get_post_meta( $wp_query->post->ID, '_filters', true );

if ( $filters && is_array( $filters ) && $filters[0] !== '' ) {
	$has_filters = 'has-filters';
	$filters_nr  = count( $filters );
} else {
	$has_filters = 'no-filters';
	$filters_nr  = 0;
}
?>


<div id="content" class="filter-content <?php echo esc_attr( $has_filters ); ?>">

	<div class="container clearfix <?php echo esc_attr( $artists_layout ); ?>">

		<div class="grid-wrapper clearfix" data-grid="artists-grid">
			
			<div class="filters-wrapper filter-<?php echo esc_attr( $filters_nr ); ?> container clearfix">
				
				<?php if ( $has_filters === 'has-filters' && in_array( 'genres', $filters ) ) : ?>
				<div class="filter" data-obj='{"action": "noisa_artists_filter", "filterby": "taxonomy", "cpt": "noisa_artists", "tax": "noisa_artists_genres", "limit": "<?php echo esc_attr( $limit ); ?>"}' >
					<div class="filter-dropdown">
						<div class="filter-collpase-btn">
							<h4 class="filter-title-anim"><?php esc_attr_e( 'Filter by', 'noisa' ); ?></h4>
							<h4 class="filter-title filter-title-anim" data-filter-name=""><?php esc_attr_e( 'All Genres', 'noisa' ); ?></h4>
							<span class="filter-btn-icon"></span>
						</div>
						<div class="filter-dropdown-content">
							<ul data-filter-group="">
								<li><a href="#" data-filter-name="all"><h3><?php esc_attr_e( 'All Genres', 'noisa' ); ?></h3></a></li>
									<?php 
										$term_args = [ 'hide_empty' => '1', 'orderby' => 'name', 'order' => 'ASC' ];
										$terms     = get_terms( 'noisa_artists_genres', $term_args );
									if ( $terms ) {
										foreach ( $terms as $term ) {
											echo '<li><a href="#" data-filter-name="' . esc_attr( $term->term_id ) . '"><h3>' . $term->name . '</h3></a></li>';
										}
									}
									?>
							</ul>
						</div>
					</div>

				</div>
				<!-- .filter -->
				<?php endif ?>
				
				<?php if ( ( $has_filters === 'has-filters' && in_array( 'categories', $filters ) ) || ( $has_filters === 'no-filters' ) ) : ?>
				<div class="filter" data-obj='{"action": "noisa_artists_filter", "filterby": "taxonomy", "cpt": "noisa_artists", "tax": "noisa_artists_cats", "limit": "<?php echo esc_attr( $limit ); ?>"}' >
					<div class="filter-dropdown">
						<div class="filter-collpase-btn">
							<h4 class="filter-title-anim"><?php esc_attr_e( 'Filter by', 'noisa' ); ?></h4>
							<h4 class="filter-title filter-title-anim" data-filter-name=""><?php esc_attr_e( 'All Categories', 'noisa' ); ?></h4>
							<span class="filter-btn-icon"></span>
						</div>
						<div class="filter-dropdown-content">
							<ul data-filter-group="">
								<li><a href="#" data-filter-name="all"><h3><?php esc_attr_e( 'All Categories', 'noisa' ); ?></h3></a></li>
									<?php 
										$term_args = [ 'hide_empty' => '1', 'orderby' => 'name', 'order' => 'ASC' ];
										$terms     = get_terms( 'noisa_artists_cats', $term_args );
									if ( $terms ) {
										foreach ( $terms as $term ) {
											echo '<li><a href="#" data-filter-name="' . esc_attr( $term->term_id ) . '"><h3>' . $term->name . '</h3></a></li>';
										}
									}
									?>
							</ul>
						</div>
					</div>

				</div>
				<!-- .filter -->
				<?php endif ?>
			</div>

			<div class="masonry <?php echo esc_attr( $gap ); ?> artists-grid masonry-anim clearfix">	
				<?php
				// Posts number
				$temp_query_count = new WP_Query();
				$temp_query_count->query( [ 'post_type' => 'noisa_artists', 'post_status' => 'publish', 'showposts' => -1 ] );
				$posts_nr = $temp_query_count->post_count;

				// Thumb size
				$thumb_size = 'full';

				// Begin Loop
				$args     = [
					'post_type' => 'noisa_artists',
					'orderby'   => 'menu_order',
					'order'     => 'ASC',
					'showposts' => $limit,
				];
				$wp_query = new WP_Query();
				$wp_query->query( $args );
				?>
			
			<?php 
			if ( have_posts() ) :
				while ( have_posts() ) :
					the_post(); 
					?>

					<?php if ( has_post_thumbnail() ) : ?> 
					<article <?php post_class( 'masonry-item masonry-item-1-3' ); ?>>
						<div class="grid-media">
							<?php 
								$thumb_classes = 'thumb thumb-desc';
								$tip           = get_post_meta( $wp_query->post->ID, '_tooltip', true ); 
							if ( isset( $tip ) && $tip !== '' ) {
								$thumb_classes .= ' tip';
							} else {
								$tip = false;
							}
							?>
							<a href="<?php echo esc_url( get_permalink() ); ?>" class="<?php echo esc_attr( $thumb_classes ); ?>" data-icon="plus">
							 
								<?php $img_src = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), $thumb_size ); ?>
								<img src="<?php echo esc_url( $img_src[0] ); ?>" alt="<?php esc_attr_e( 'Post Image', 'noisa' ); ?>">
								
								<div class="desc-layer">
									<div class="desc-details">
										<?php the_title( '<h2 class="grid-title">', '</h2>' ); ?>
										<div class="grid-cats">
											
											<?php 
												$categories = get_the_terms( $post->ID, 'noisa_artists_genres' );
												$separator  = ' / ';
												$cats       = '';
											if ( ! empty( $categories ) ) {
												foreach ( $categories as $term ) {

													$cats .= '<span>' . esc_html( $term->name ) . '</span>' . $separator;
												}
											}
												echo trim( $cats, $separator );

											?>

										</div>
									</div>
								</div>
								<?php if ( $tip ) : ?>
									<div class="tip-content hidden">
										<?php $noisa_opts->e_esc( $tip ); ?>
									</div>
									<!-- .tooltip -->
								<?php endif; ?>
							</a>
						</div>
					</article>
				<?php endif; // end has_post_thumbnail ?>

									<?php endwhile; // End Loop ?>
				<?php endif; ?>
			</div>
			<div class="clear"></div>

			<div class="load-more-wrap text-center 
			<?php 
			if ( $posts_nr <= $limit ) {
				echo esc_attr( 'hidden' ); } 
			?>
			">
				<a href="#" data-pagenum="2" class="btn btn-medium load-more"><span class="icon-wrap"><span class="icon"></span></span> <?php esc_html_e( 'Load more', 'noisa' ); ?></a>
			</div>

			<div class="ajax-messages">
				<div class="message ajax-error">
					<span class="message-title">
						<?php esc_html_e( 'Upsss!', 'noisa' ); ?>
					</span>
					<span class="message-body">
						<?php esc_html_e( 'Sorry, something went wrong and we cannot retrieve any results.', 'noisa' ); ?>
					</span>
				</div>
			</div>

		</div> 
		<!-- .grid wrapper -->
	</div>
	<!-- .container -->
</div>
<!-- #content -->

<?php
// Get orginal query
$post     = $temp_post;
$wp_query = $query_temp;

get_footer();